/**	ProjectCreation.js
 *	@author: RIMC
 */

var gProjectCreationStarted = false; // Flag to say if Project Creation has been started yet
var gProjectCreationTypeFixed = false; // Flag to say if project creation type is not selectable
var gProjectCreationType = ""; // Type of Project Creation. "TemplateProject", "BlankProject" or "CopyProject"
var gProjectSelectBox = null; // Project Select Box used during project Creation
var gProjectCreationForm = {name:"SHOW", manager:"SHOW", customer:"SHOW", description:"SHOW", dueDate:"SHOW", 
	uploadDoc:"SHOW", bom:"SHOW", replaceGroups:"SHOW", inviteMembers:"SHOW", setAttributes:"SHOW", setThumbnails:"SHOW",
	setStatus:"SHOW", defaultPlanning:"BACKWARD"};
var gRolesRequired = new Array(); // Array of IDs of required roles (must be assigned during project creation)
var gProjectDocumentList = null; // Array to store Project Documents. Will be accessed by Documents table
var gProjectID; // The Id of the template or project
var gSourceProjectID; // The Id of the source project. When set, attribute values, role assignment and company/locations will be taken from this project
var gTemplateDocumentList = null; // Array to store Template Documents. Will be accessed by Documents table
var gTemplateProjectID; // The Id of the document template project
var gNewProjectID;
var gProjectFolders = null;   // Array containing all folders of gNewProjectID project, where logged in user can upload documents
var gBOMEnabled = 1; //indicated if BOM is enabled on a system wide level
var gCopyBOM;
var gSBoxes;

function showTempProjectDropDownList(gProjectCreationType, langStrings, selectedValue, i18nDocUConfLangArr) 
{
		var selectBoxId;
		
		if (!gSBoxes){
			gSBoxes = {};
		}
		if (typeof selectCopyOptions === "undefined"){
			selectCopyOptions = function(){};
		}
		
		if(gProjectCreationType == "TemplateProject") {
			selectBoxId = "#selectTemplateId";
			// Show the template row
			$("#selectTemplateRowId").show();
			// only create one instance of the sDrop for templates
			if (!gSBoxes.templates){
				gSBoxes.templates = {};
				require(["component/sdrop/SDrop", "component/sdrop/dataproviders/SDropDataProvider"], function(SDrop, SDropDataProvider){
					var options = {	
							'onChangedByUser':	selectCopyOptions.bind($(selectBoxId)[0], $(selectBoxId)[0], false),
							'autoload': false,
							'manageStyleAndWidth' : false,
							'initializeDataProvider': false};
					if(selectedValue){
						options.initialValue = selectedValue;
					}
						
					gSBoxes.templates = new SDrop(	$(selectBoxId), 
													$('#sbox_loader_templ'), 
													new SDropDataProvider({'dataSource':"GetNameIDList.jsp?list=Templates"}),
													options
													);
	
					gSBoxes.templates.redraw();			
					// load templates
					gSBoxes.templates.searchFor('');				
				});
			} else if (gSBoxes.templates.redraw){
				gSBoxes.templates.redraw();			
				// load templates
				gSBoxes.templates.searchFor('');
			}
			
		} else if(gProjectCreationType == "CopyProject") {
			selectBoxId = "#selectProjectId";
			// Show the Projects Row
			$("#selectProjectRowId").show(); 
			
			// only create one instance of the sDrop for projects
			if (!gSBoxes.projects){
				gSBoxes.projects = {};
				require(["component/sdrop/SDrop", "component/sdrop/dataproviders/SDropDataProvider"], function(SDrop, SDropDataProvider){
					var options = {	
							'onChangedByUser':	selectCopyOptions.bind($(selectBoxId)[0], $(selectBoxId)[0], true),
							'autoload': false,
							'manageStyleAndWidth' : false};
					if(selectedValue){
						options.initialValue = selectedValue;
					}
					gSBoxes.projects = new SDrop(	$(selectBoxId), 
												$('#sbox_loader_proj'), 
												new SDropDataProvider({'dataSource':"GetNameIDList.jsp?list=Projects"}),
												options);
					gSBoxes.projects.redraw();				
					
					//load first 200 projects
					gSBoxes.projects.searchFor('');
				});
			} else if (gSBoxes.projects.redraw){
				gSBoxes.projects.redraw();				
				
				//load first 200 projects
				gSBoxes.projects.searchFor('');
			}
			
		} 
		else if (gProjectCreationType == "NoTemplate")
		{
			return ; 
		}
		else {
			// Blank Project, no second select box
			createProject(i18nDocUConfLangArr);
			return;
		}
}


// Function called when type of project is selected
function loadProjectCreationInfo(dropDownMenu) {
	
	// If Project Creation already started warn the user
	if(gProjectCreationStarted) 
	{
		var yes = confirm(langStrings.projectCreationWarning);
		if(!yes)
		{
			dropDownMenu.value = gProjectCreationType;
			return;
		}
	}
	
	if(dropDownMenu.value == "")
		return;
	
	// Set the project Creation type
	gProjectCreationType = dropDownMenu.value;
	// Sets hidden field for use in front end later
	$("#creationTypeId").val(gProjectCreationType);
	
	
	// Clear the page. Could be a reselection of first drop down
	resetPage();	
}

/**
 * Create a new project creation form.
 * @param {array} i18nDocUConfLangArr - Document Upload Configuration language tags array.
 */
window.createProject = function (i18nDocUConfLangArr) {
	
	// Hide everything to the user except a wait message at top of page
	$("#mainTableId > div").not("#messageRowId").addClass("displayNone").hide();
	$("#messageRowId").removeClass("displayNone").show();
	
	require(["component/smartnames/savedsearchcontext/SavedSearchContextInfo",
	         "component/smartnames/savedsearchcontext/ProjectCreationDetailsDynamicSmartNameCollector", 
	         "attributecategory/AttributeCategory",
	         "component/smartnames/savedsearchcontext/AttributeCategoryDynamicSmartNameCollector", 
	         "utils/ObjectArrayCloneUtil",
	         "utils/ManageRoles"], 
	         function (SavedSearchContextInfo,
	        		 ProjectCreationDetailsDynamicSmartNameCollector, 
	        		 AttributeCategory, 
	        		 AttributeCategoryDynamicSmartNameCollector, ObjectHandler, ManageRoles) {

		// show what has been hidden 
		$('select').not('.sdrop,select .sdrop').show();	

		// Set the project Creation type
		if(gProjectCreationType == "BlankProject")
		{
			//reset the 'projectID' input parameter value
			gProjectID = null;
			$("#projectIDId").prop("value", "");
		}
		
		// Check to see that Project Creation hasn't already been started
		if(gProjectCreationStarted) 
		{
			var yes = confirm(langStrings.projectCreationWarning);
			if(!yes)
			{
				$("#mainTableId > div").not("#messageRowId").removeClass("displayNone").show();
				$("#messageRowId").addClass("displayNone").hide();
				
				if(gProjectCreationType != "BlankProject") 
				{
					var boxId = "#" + gProjectSelectBox.id + " option[value='" + gProjectID + "']"; // jQuery selector
					$(boxId).prop("selected", true);
				}
				return ;
			}
			else {
			
				gProjectID = gNewProjectID ;
			
				resetPage();		
			}
		}
		else 
			if(gProjectCreationType != "BlankProject")
			{
				if (gProjectCreationTypeFixed) 
					gProjectID = $("#selectTemplateId")[0].value;
				else
					gProjectID = gProjectSelectBox.value;			
			}	
				
				
		
		// URL Parameters for project copying
		var URLParam = "";
		if(gProjectCreationType != "BlankProject") {
			// Get the selected project ID first
			URLParam = "&projectID=" + gProjectID;
			
			// Get the copy options next
			// Ask this to the CopyProjectOptionsTable component.
			var copyTable = $("#projectCopyOptionsTable").get(0).CopyProjectOptionsTable;
			if(gProjectCreationType === "CopyProject") {
				// If the user was able to enter them, get the values the user entered
				URLParam += "&" + copyTable.getSelectedOptions();
			} else {
				// Otherwise, get the values for the template. 
				// For templates we don't show the popup, but we still need the values of those checkboxes.
				// Do not ask for the selected options as they could have been modified by the user if he changed his mind...
				URLParam += "&" + copyTable.getTemplateCopyOptions();
			}
		}
		
		// if the source project is known, add the source project id 
		if (gSourceProjectID != null &&  gSourceProjectID.length>0){
			URLParam += "&sourceprojectID=" + gSourceProjectID;
		}

		if(!$("[name=copyOptionFolders]").is(":checked")){
			gProjectFolders = []; // make sure no folders can be selected
		}
		
		try {
			ajax({
				url: "GetProjectCreationInfo.jsp?action=LoadProject" + URLParam,
				type: "GET",
				data: "xml",
				debug: false,
				timeout: 120000,
				synchronous: false,
				onError: function(status) {
				//window.alert("Unable to get project creation info. Server status: "+status);
				},
				onSuccess: function(xml) {
				//-----------------------------------------------------------------
				//define a custom "Group" Object to store Group data as a JS object
				//-----------------------------------------------------------------
				
					if(gProjectCreationType != "BlankProject") {
						// First we get the project ID and put it into a hidden field
						var projectID = WCXML.GetElementText(xml, "copy_project_id", true);
						$("#projectIDId").prop("value", projectID);
					}
					
					// Get the attribute category id
					var projectCategoryID = WCXML.GetElementText(xml, "project_category_id", true);

					// Next get the possible Requestor groups (same as for PM groups for PM Selector)
					var requestorSelectBox = $("#selectRequestorId")[0];
					if (requestorSelectBox!=null)
					{
						var groupList = xml.getElementsByTagName("pm_groups");
						if(groupList.length > 0) {
							var groups = groupList[0].getElementsByTagName("group");	
						
							if(groups.length > 0) {
								var groupOption = document.createElement('option');
								groupOption.text = "---";
								groupOption.value =  "N/A";
								groupOption.setAttribute("disabled", "disabled");
							
								try{
									requestorSelectBox.add(groupOption, null );	
								} catch(ex) { 
									requestorSelectBox.add(groupOption); // IE 
								}						
							}
						
							for ( var i = 0  ; i < groups.length ; i++ ) {
								var group = groups[i];
								var groupID = group.getAttribute("id");
								var groupName = WCXML.GetElementText(group, "name", false);
							
								var groupOption = document.createElement("option");
								groupOption.text = groupName;
								groupOption.value =  groupID;
							
								try{
									requestorSelectBox.add(groupOption, null );	
								} catch(ex) { 
									requestorSelectBox.add(groupOption); // IE 
								}
							}
						}
					}
					
				
					// Fill the selectProjectStatusId select with appropriate project statuses
					var projectStatusSelectBox = $("#selectProjectStatusId")[0];
					var projectStatusList = xml.getElementsByTagName("selected_project_statuses_list");
	                                var completeProjectStatusListElms = xml.getElementsByTagName("project_status_list")[0].getElementsByTagName("custom_project_status");
	                                var systemProjectStatusListElms = xml.getElementsByTagName("system_project_statuses_list")[0].getElementsByTagName("custom_project_status_id");
	                                
	                                completeProjectStatusList = {};
	                                systemProjectStatusList = {};
	                                //needed, because IDs were moved from ID attribute(by which the systemProjectStatusListElms array would be associative with id index) to textContent
	                                for ( var i = 0  ; i < completeProjectStatusListElms.length ; i++ ) {
	                                	completeProjectStatusList[WCXML.GetElementAttribute(completeProjectStatusListElms[i], "id")] = completeProjectStatusListElms[i];
	                                }
	                                for ( var i = 0  ; i < systemProjectStatusListElms.length ; i++ ) {
	                                	systemProjectStatusList[WCXML.GetElementSelfTextContent(systemProjectStatusListElms[i])] = systemProjectStatusListElms[i];
	                                }

	                                
	                                var notSelectedOption = true;

	                                if(projectStatusList.length > 0) {
	                                    var selectedStatuses = projectStatusList[0].getElementsByTagName("custom_project_status_id");
	                                        projectStatusSelectBox.innerHTML='';                              

	                                        for ( var i = 0  ; i < selectedStatuses.length ; i++ ) {
	                                                var status = selectedStatuses[i];
	                                                var statusID = WCXML.GetElementSelfTextContent(status);

	                                                if(systemProjectStatusList[statusID]) {
	                                                    var statusName = WCXML.GetElementText(completeProjectStatusList[statusID], "status_name", false);
	                                                    //check,if the translation tag is available 
	                                                    var statusTranslation = WCXML.GetElementText(completeProjectStatusList[statusID], "translation_tag", false);
	                                                    if (statusTranslation) {
	                                                    	//get the translation for the tag(loaded previously) 
	                                                    	statusTranslation = langStrings.ProjectStatusesTranlation[statusTranslation];
	                                                    }
	                                                    
	                                                                                                        
	                                                    var statusOption = document.createElement("option");
	                                                	if (statusTranslation) {
	                                                		//id the translation exists
	                                                		statusOption.text = statusTranslation;
	                                                	} else {
	                                                		statusOption.text = statusName;
	                                                	}

	                                                    
	                                                    statusOption.value =  statusID;

	                                                    /*
	                                                     * set selected option - this testing is to find, wheter the status has already been selected and if not, then check,
	                                                     * if the current is (first) active one, which is to be set as selected in a dropdown box
	                                                     */
	                                                    if (notSelectedOption) {
	                                                        try{
	                                                            var isActive = parseInt(WCXML.GetElementText(completeProjectStatusList[statusID], "is_active", false));
	                                                            if (parseInt(isActive) > 0) {
	                                                                //statusOption.selected = "selected";
	                                                                statusOption.setAttribute( "selected", "selected" );
	                                                                //statusOption.selected = true;
	                                                                //statusOption.select();

	                                                                notSelectedOption = false;
	                                                            }                                                            
	                                                        } catch(ex) {
	                                                            //don't need to do any action - it's just preselecting some project status. Nothing is really bad, if it fails
	                                                        }
	                                                    }

	                                                    try{
	                                                            projectStatusSelectBox.add(statusOption, null );
	                                                    } catch(ex) {
	                                                            projectStatusSelectBox.add(statusOption); // IE
	                                                    }
	                                                }
											}
	                                }

					
					// Next get the Roles and add them to Project Members Table
					var hideRolesTable = true;
					var hidePlanning = true;
					var hideRequestor = true ; 
					var hideDueDate = false;
					gRolesRequired = new Array();
					
					if(gProjectCreationType != "BlankProject") 
					{
						var roleSetupList = xml.getElementsByTagName("project_creation_role_setup");
						
						if(roleSetupList.length > 0) 
						{
							
							//retrieve the current value of 'Invite Group Role Assignment Default' preference
							var invitegroupdef = WCXML.GetElementText(xml, "invite_group_default", true);
							if (invitegroupdef != null && invitegroupdef == "1") {
								invitegroupdef = true;
							} else {
								invitegroupdef = false;
							}		
													
							// Read the Role setup list from the XML.
							var rolesToManageList = new Array();
							var roleSetup = roleSetupList[0].getElementsByTagName("role_setup");
							if (roleSetup.length > 0) {
								for (var i = 0  ; i < roleSetup.length ; i++) {
									var role = {};
									role.id = WCXML.GetElementText(roleSetup[i], "role_id", false);
									role.name = WCXML.GetElementText(roleSetup[i], "role_name", false);
									role.show = WCXML.GetElementText(roleSetup[i], "show", false) == '1';
									role.showActions = WCXML.GetElementText(roleSetup[i], "allow_multiple", false) == '1';
									role.required = WCXML.GetElementText(roleSetup[i], "required", false) == '1';
									role.defAssigneeName = WCXML.GetElementText(roleSetup[i], "default_assignee", false);
									role.assignedGroups = new Array();
									role.assignedUsers = new Array();
									
									rolesToManageList.push(role);
									
									// manage list of the required roles IDs
									if (role.required)
										gRolesRequired.push(role.id);
								}
							}
							
							// Read the assigned users and groups from the XML.
							var roleAssignments = xml.getElementsByTagName("project_role_assignment_map");
							for (var k = 0; k < roleAssignments.length; k++) {
								
								var groupID = roleAssignments[k].getElementsByTagName("role_group")[0].getAttribute("id");
								var role = null;
								for (var j=0; j < rolesToManageList.length; j++) {
									if (rolesToManageList[j].id == groupID) {
										role = rolesToManageList[j];
										break;
									}
							}
							
								if (role) {
									var assignedGroups = roleAssignments[k].getElementsByTagName("assigned_group");
									var assignedUsers = roleAssignments[k].getElementsByTagName("assigned_user");
							
									if (assignedGroups.length > 0) {
										for (var i=0; i < assignedGroups.length; i++) {
											var assignedGroup = {};
											assignedGroup.id = assignedGroups[i].getAttribute("id");
											assignedGroup.name = WCXML.GetElementText(assignedGroups[i], "assigned_group_name", false);
								
											var assigneeXml = assignedGroups[i].getElementsByTagName("assigned_group_assignee");
											if (assigneeXml.length > 0) {
												assignedGroup.assignee = {};
												var curUserAssignmentUser = WCXML.GetFirstFirstLevelChild(assigneeXml[0], "user");
												
												var curUserAssignmentUserFirstName = WCXML.GetElementText(curUserAssignmentUser, "first_name");
												var curUserAssignmentUserLastName =  WCXML.GetElementText(curUserAssignmentUser, "last_name");
												var curUserAssignmentUserUserName =  WCXML.GetElementText(curUserAssignmentUser, "name");
												var curUserAssignmentUserActive =   WCXML.GetElementText(curUserAssignmentUser, "is_active");
												var curUserAssignmentUserID = WCXML.GetElementAttribute(curUserAssignmentUser, "id");
											
												var userAssignmentData = {};
												userAssignmentData.firstName = curUserAssignmentUserFirstName;
												userAssignmentData.lastName = curUserAssignmentUserLastName;
												userAssignmentData.userName = curUserAssignmentUserUserName;
												userAssignmentData.isActive = curUserAssignmentUserActive;										
												userAssignmentData.id = curUserAssignmentUserID;
											
												assignedGroup.assignee = userAssignmentData;
											} else {
												assignedGroup.assignee = null;
											}
									
											role.assignedGroups.push(assignedGroup);
										}
									}
									
									if (assignedUsers.length > 0) {
										for (var i=0; i < assignedUsers.length; i++) {
											var currentUserRoleAssignment = assignedUsers[i];
											
											var curUserAssignmentUser = WCXML.GetFirstFirstLevelChild(currentUserRoleAssignment, "user");
											var curUserAssignmentUserFirstName = WCXML.GetElementText(curUserAssignmentUser, "first_name");
											var curUserAssignmentUserLastName =  WCXML.GetElementText(curUserAssignmentUser, "last_name");
											var curUserAssignmentUserUserName =  WCXML.GetElementText(curUserAssignmentUser, "name");
											var curUserAssignmentUserActive =   WCXML.GetElementText(curUserAssignmentUser, "is_active");
											var curUserAssignmentUserID = WCXML.GetElementAttribute(curUserAssignmentUser, "id");
										
											var userAssignmentData = new Object();
											userAssignmentData.firstName = curUserAssignmentUserFirstName;
											userAssignmentData.lastName = curUserAssignmentUserLastName;
											userAssignmentData.userName = curUserAssignmentUserUserName;
											userAssignmentData.isActive = curUserAssignmentUserActive;										
											userAssignmentData.id = curUserAssignmentUserID;
											
											role.assignedUsers.push(userAssignmentData);
										}
									}
								}
							}
							
							// if there are no roles to show ...
							if (rolesToManageList.length > 0) {
					 			hideRolesTable = false;
							}
							
							
							// Creat the roleManagement object and add the assigneetable to the page.
							var roleMgr = new ManageRoles.roleManagement(gProjectID, rolesToManageList, i18n, gMenu_file, invitegroupdef);
					 		var roleMgrHolder = $("#RoleManagementHolder")[0];
					 		roleMgrHolder.innerHTML = "";
					 		var roleTable = roleMgr.getAssigneeTable();	 		
					 		roleTable.setAttribute('width',"100%");
					 		roleMgrHolder.appendChild(roleTable);
						}
						
						// Decide if we are to hide planning box
						var numberOfTasks = WCXML.GetElementText(xml, "no_of_project_tasks", false);
						if(numberOfTasks != null && numberOfTasks.length > 0) {
							var hasDueDateAttributeLink = WCXML.GetElementText(xml, "tasks_duedate_attribute_link", false) == '1';
							var intNoOfTasks = parseInt(numberOfTasks);
							if((intNoOfTasks>0) && !hasDueDateAttributeLink && !((gProjectCreationType=="CopyProject") && !($("input[name='copyOptionTasks']").prop('checked'))))
								hidePlanning = false;							
						}
						
						// Decide if we are to hide the project due date box
						var hasDueDateAttributeLink = WCXML.GetElementText(xml, "project_duedate_attribute_link", false) == '1';
						if(hasDueDateAttributeLink) {
							hideDueDate = true;					
						}
						
						// Decide if we are to hide the requestor group box 
						var requestorGroupExists = WCXML.GetElementText(xml, "requestor_group_exists", false);
						if(requestorGroupExists != null && requestorGroupExists.length > 0) {
							var requestorExists = parseInt(requestorGroupExists);
							if(requestorExists== 1)
							{
								hideRequestor = false;
							}							
						}
						
						
							// Get Template (not Project) Documents in the project for document selector
							var nodethumbnailList = xml.getElementsByTagName("template_doc_thumbnail");
							gTemplateDocumentThumbnailList = new Array();
						if(nodethumbnailList != null && nodethumbnailList.length > 0) {
								var node = 0;
								for(node = 0; node < nodethumbnailList.length; node++) 
								{
									var docVersionId = nodethumbnailList[node].getElementsByTagName( "id");
									var id = WCXML.textContent(docVersionId[0]) ;
									var thumbnailElem = nodethumbnailList[node].getElementsByTagName( "thumbnail");
									var thumbnail = WCXML.textContent(thumbnailElem[0]);
									gTemplateDocumentThumbnailList.push({id: id , thumbnail: thumbnail});						 
								}
							}
							
							// Get the document creation setup and inject it to generated HTML (still XML encoded)
							var docCreationSetupXmlNodes = xml.getElementsByTagName("doccreation_setup_xml");
							// This is for both "Documents" and "Bill Of Materials" sections on create project page
							if (docCreationSetupXmlNodes && docCreationSetupXmlNodes.length > 0) {
								$("#documentSourcesTextArea").val(WCXML.GetElementSelfTextContent(docCreationSetupXmlNodes[0]) );							
							}
							
							// Get the document rendering configuration and inject it to generated HTML (still XML encoded)
							var docRenderingConfigXmlNodes = xml.getElementsByTagName("docrenderingsetup");
							if (docRenderingConfigXmlNodes && docRenderingConfigXmlNodes.length > 0) {
								$("#DocRenderConfigXML").val(WCXML.GetElementSelfTextContent(docRenderingConfigXmlNodes[0]) );							
							}
							
						// reset doc template globals
							gTemplateProjectID = WCXML.GetElementText(xml, "template_project_id", false);
							gTemplateDocumentList = new Array();
							gTemplateDocsLoaded = false;
							gHasTemplateDocuments = false;								
						
							var nodeList = xml.getElementsByTagName("template_docs");
							if(nodeList != null && nodeList.length > 0) {
								var node = 0;
								for(node = 0; node < nodeList.length; node++) {
									var projectDocuments = nodeList[node].getElementsByTagName("doc_version_checkout");
//									var projectDocuments = xml.getElementsByTagName("doc_version_checkout");
									if(projectDocuments != null && projectDocuments.length > 0) {
										var g = 0;
										for(g = 0; g < projectDocuments.length; g++) {
											var projectDocument = projectDocuments[g].getElementsByTagName("doc_version");
											var documentId = WCXML.GetElementText(projectDocument[0], "document_id", false);
											var docVersionId = WCXML.GetElementAttribute(projectDocument[0], "id");
											var documentElem = projectDocument[0].getElementsByTagName("document");										
											var documentName = WCXML.GetElementText(documentElem[0], "name", false);
											var categoryId = WCXML.GetElementText(projectDocument[0], "category_id", false);
											// Get the folder; we rely on it sitting two levels outside the doc_version_checkout (if it exists)
											var folderName = "";
											if (projectDocuments[g].parentNode != null) {
												var folderElem = projectDocuments[g].parentNode.parentNode;
												if (folderElem != null) {
													if (folderElem.tagName == "folder")
														folderName = WCXML.GetElementText(folderElem, "name", false);
												}
											}
											// Add Info to Array
											gTemplateDocumentList.push({id: documentId, docverid: docVersionId, name: documentName, categoryid: categoryId, foldername: folderName});
										}
									}
									if (gTemplateDocumentList.length > 0 ) {
										gTemplateDocsLoaded = true;
										gHasTemplateDocuments = true;								
									}
								}
							}
						
							// If we have template documents: enable the New document option - otherwise disable
							setHasNewDocumentOption(gHasTemplateDocuments);
							
						// If we have template documents: enable the New document option - otherwise disable
						setHasNewDocumentOption(gHasTemplateDocuments);
						
					} else {
						
						// Blank project: we have no template documents: hide the New document option
						gHasTemplateDocuments = false;
						setHasNewDocumentOption(false);
					}

					// set additional document select options
					setHasLinkBrowseDocumentOption(false); // disabled for simplicity
					setHasCopyDocumentOption(true);				
					// For now we do not want the list delete controls
					setHasListDeleteOption(false);
					hideShowFolderColumns();				
					showHideAddDocumentOptions();
					
					//initialize Autonaming settings per Document Type
					loadDocTypeSettings(xml);
					
					// Support for source document. Check whether you have a source document(s) selected, if so, create the rows and initialize it to the selected source document
					var source_ids = $(".source_doc_id");
					var sourceDocsInfo = [];
					if (source_ids !=null)
					{
						for (var i = 0 ; i<source_ids.length ; i++){
							var documentId = source_ids[i].value;
							var documentName = $("#source_document_" + documentId).val();
							var documentDesc = $("#source_document_" + documentId + "Desc").val();
							var documentThumb = $("#source_document_" + documentId + "Thumb").val();
							// add docInfo object to render the document(s) in DocTableX
							sourceDocsInfo.push({
								docName: documentName,
								docDesc: documentDesc,
								docVerID: documentId,
								thumbnailURL: documentThumb
							});
						}
					} 
					
					// Project creator XDrop
					var isProjectManager = ($("#userIsPMId")[0].value == '1' );
					
					var userID = $("#userID")[0].value ; 
					var userName = $("#userName")[0].value ; 
					var userFirstName = $("#userFirstName")[0].value ; 
					var userLastName = $("#userLastName")[0].value ; 
					
					var currentuser = { 'userID':userID, 'userName': userName,'userFirstName':userFirstName,'userLastName':userLastName  };
					
					require(["pages/projectcreation/ProjectCreation"],	function(ProjectCreation){
						var composite = ProjectCreation.ProjectManagerDataProvider.create(isProjectManager,currentuser);
						var renderers =ProjectCreation.ProjectManagerDataProvider.renderers();
						var xdrop = new ProjectCreation.XDrop(composite, renderers, {
							absoluteXDropPanel: true,
							blacklistSelectedEntry: false,
							placeholder: ProjectCreation.i18n.t("FilterPlaceholder")
						});
						
						var div = $(document.querySelector("#projectManagerSelectId"));
						div.empty().append(xdrop.getElement());
						xdrop.getElement().attr("data-sahi-id", "projectManagerSelectId");
						// append/remove selected/deselected items as hidden input to dom.
						ProjectCreation.FormEntryXDrop(xdrop, "selectProjectManager", {
							id: "getFormId",
							ctx: div
						});
						if (isProjectManager){
							var user = new ProjectCreation.WebCenterUser(userID, userName, userFirstName, userLastName, '', true);
							var defaultValue = new ProjectCreation.ResultEntry("user", user);
							xdrop.setValue( defaultValue);
						}
					});					
					
					
					// load SDrop and store in selector object for reuse
					var skipRoles = (gProjectCreationType != "BlankProject");
					
					require(["pages/projectcreation/ProjectCreationMembersXDrop", "component/xdrop/utils/FormEntryXDrop"], function(ProjectCreationMembersXDrop, FormEntryXDrop){
						var xdrop = new ProjectCreationMembersXDrop(skipRoles);
						var div = $(document.querySelector("#inviteMembersSelectId"));
						div.empty().append(xdrop.getElement());
						xdrop.getElement().attr("data-sahi-id", "InviteMembers");
						// append/remove selected/deselected items as hidden input to dom.
						FormEntryXDrop(xdrop, "invitedMembers", {
							id: "getFormId",
							ctx: div
						});						
					});
			        
					// Used to collect the context & "dynamic" values of the SmartNames on the page... (for Saved Search with SmartNames)
					var savedSearchContextInfo = new SavedSearchContextInfo();
					savedSearchContextInfo.setProjectId(gTemplateProjectID || gProjectID);
					savedSearchContextInfo.pushCollector(new ProjectCreationDetailsDynamicSmartNameCollector());
					
					// put the green links at the bottom of the document section
					var docTableDiv = 'documentsTableContainerDiv';
					var docTableHiddenDiv = 'documentsTableHiddenDiv';		
					
					initDocTableX(
							'documentSourcesTextArea', 
							docTableDiv,
							'documentSourcesHiddenDiv', 
							docTableHiddenDiv,
							'AddDocumentProjCreateGreenLinkTd', 
							'ProjectCreateDocument',
							'ProjectDocuments',
							i18nDocUConfLangArr, 
							null, 
							(gBOMEnabled ? true : false), 
							savedSearchContextInfo,
							gProjectID,
							true,				   	// project creation context
							sourceDocsInfo,			// source documents to display
							gProjectFolders);			// target folders
					
					// Project Creation has started
					gProjectCreationStarted = true;
					
					// Show everything to the user again
					$("#mainTableId > div").not('.sdrop').show();
					$(".alwaysHidden").hide();  // HADW: whatever you really don't want to see, give it class alwaysHidden. First use is documentSourceHandler hidden objects
					
					
					// Hide the required flags
					$('#mainTableId span[id$="ReqId"]').hide();
					//$("#mainTableId tr td span").hide();

					if(gProjectCreationType == "TemplateProject") {
						$("#selectProjectRowId").hide();
					} 
					else if(gProjectCreationType == "CopyProject") {
						if(gProjectCreationTypeFixed)    // when the type is fixed, we show the selectTemplateRowId, this contains read only info on the selected project 
							$("#selectProjectRowId").hide();
						else
							$("#selectTemplateRowId").hide();
					} else { // It could be a blank project
						$("#selectProjectRowId").hide();
						$("#selectTemplateRowId").hide();
					}
					

					if(gProjectCreationTypeFixed)
						$("#projectTypeSelectRowId").hide();
					
					
					// Process the gProjectCreationForm Info (hides not selected sections)
					processProjectCreationFormValues(xml);				
					
					// Load BOM
					if (gProjectCreationType === "BlankProject") {
						// Clear block
						var bomBlock = $("#projectBOMBlockId");
						bomBlock.empty();
						// Hide section
						$("#mainBomDetailsRowId").hide();
					} else {
						if (gProjectCreationForm.bom !== "DONT_SHOW") {
							// Show section
							$("#mainBomDetailsRowId").show();
							if (gProjectCreationType === "TemplateProject") {
								// To fetch BOM table for Templates
								gCopyBOM = "1";
							} else if (gProjectCreationType === "CopyProject") {
								// Value from options dialog
								gCopyBOM = WCXML.GetElementText(xml, "is_copy_bom",
										false);
							} else {
								gCopyBOM = "0";
							}
							loadBOM(i18nDocUConfLangArr);
						}
					}
					
					
					// Set default planning method
					if (gProjectCreationForm.defaultPlanning == "FORWARD")
						$("#projectPlanningId option:eq(0)").prop("selected", true);
					else
						$("#projectPlanningId option:eq(1)").prop("selected", true);	
					
					projectPlanningChanged();				
					
					// Hide plannining row if no tasks
					if (hidePlanning){
						$("#projectPlanningRowId").hide();
						gProjectCreationForm.planning = "DONT_SHOW"; // to avoid failure on validation
					}		
					
					// Hide due date row if needed
					if (hideDueDate)  {
						$("#projectDueDateRowId").hide();
						gProjectCreationForm.dueDate = "DONT_SHOW"; // to avoid failure on validation
					}
					
					// Hide/show the Requestor row
					if (hideRequestor){
						$("#requestorRowId").hide();
						gProjectCreationForm.requestor = "DONT_SHOW";
					} else {
						$("#requestorRowId").show();
						gProjectCreationForm.requestor = "SHOW";
					}		
					
					
					// Show project attributes
					if (projectCategoryID != null && projectCategoryID.length>0 && gProjectCreationForm.setAttributes == 'SHOW') {
						
						var readURL = "GetAttributeCategoryXML.jsp?categoryid=" + projectCategoryID;
						var valuesURL = "GetAttributes.jsp?projectid="+gProjectID;
						if (gSourceProjectID != null &&  gSourceProjectID.length>0) {
							valuesURL +=  "&sourceprojectid="+ gSourceProjectID ;
						} 

						// Check the copy options if the attributes (values) should be copied too
						var copyValues = true;
						var copyAttrTag = xml.getElementsByTagName("is_copy_attriubtes");	// 'correct' spelling ...
						if(copyAttrTag.length>0 && WCXML.GetElementSelfTextContent(copyAttrTag[0])=='0') {
							copyValues = false;
						}
						
						var currentUser = ObjectHandler.getCloneOfObject(gCurrentUser);
						currentUser.canEditAttributes = true;
						var aCatOptions = new Object();
						aCatOptions.ACatObj = "projectAttributesBlockId";
						aCatOptions.ACatPanel = "projectAttributesBlockId";
						aCatOptions.readURL = readURL + "&view=ProjectCreation&fallback=Creation";
						aCatOptions.actionURL = "";
						aCatOptions.currentUser = currentUser;
						aCatOptions.valuesURL = valuesURL;
						aCatOptions.view = 'Creation'; // even though we delay loading, still request creation vioew for terminology
						aCatOptions.delayedLoading = true;

						// Check if ProjectCreation view is available, otherwise take the creation view
						aCatOptions.callbackOnLoad = function() {		
							var aCatObj = this;
							var view = "Default";
							if(aCatObj.getViewByName('ProjectCreation')){
								view = "ProjectCreation";
							} else if (aCatObj.getViewByName('Creation')){
								view = "Creation";
							}
							
							aCatObj.activateViewByName(view);
							$("#mainTableId > div").removeClass("displayNone");
							$("#messageRowId").addClass("displayNone");
							
							if($('#projectPlanningId').val() == "forward"){
								// search for "LastTaskEnds" property in this.otherProperties list and store it in 'prop' if found
								var prop;
								if (this.otherProperties) {
									for (let propIt = 0; propIt < this.otherProperties; propIt++) {
										let pr = this.otherProperties[propIt];
										if (pr.name == "LastTaskEnds") {
											prop = pr;
											break;
										}
									}
								}
								var cell = aCatObj.findCell(prop);
								if(cell && cell.cellObj && (cell.cellObj.label == 'LastTaskEnds' || (!cell.cellObj.label && cell.cellObj.name == 'LastTaskEnds'))){
									cell.cellObj.label = 'FirstTaskStarts';
								}
							}							
						};
						
						aCatOptions.defaultHourAsHalfHours = gDefaultHourAsHalfHours;
						aCatOptions.copyValues = copyValues;
						aCatOptions.type = "project";
						aCatOptions.projectID = gProjectID;   // ID of selected template or copied project
						// creation of a new project - no project ID known yet
						
						// Let the attribute cat. know we are in "project creation" context (used in DocTableX)
						aCatOptions.projectCreationContext = true;
						
						// let category know that terminology should be used if available
						aCatOptions.useTerminology = true;
						
						// Set the saved search context here so we can also resolve intermediate smartnames specific 
						// to this page (project name, ...) instead of only the attribute category values.
						aCatOptions.overrideSavedSearchContextInfo = savedSearchContextInfo;
												
						// we need a global here... (legacy)
						window.myACat = new AttributeCategory(aCatOptions);
						
						// For Saved Search with SmartNames, use the values of the already filled in SmartNames.
						savedSearchContextInfo.pushCollector(new AttributeCategoryDynamicSmartNameCollector(window.myACat));
					}
					else {
						$("#mainTableId > div").removeClass("displayNone");
						$("#messageRowId").addClass("displayNone");
						$("#projectAttributesBlockId").empty();
						$("#mainAttributesRowId").hide();					
					}
					
					
					// Hide empty groups table
					if(hideRolesTable) {
						if(gProjectCreationForm.inviteMembers == "DONT_SHOW")
							$("#mainMembersRowId").hide(); // hide complete members section
						else
							$("#replaceGroupsRowId").hide(); // just hide group replace
							$("#inviteMembersRowId").addClass("add-spacing-top");
					}

					// Check if expand should be hidden
					checkExpand();
					  							
					// We Check if there is a custom Thumbnail
					var templateThumbnail = WCXML.GetElementText(xml, "template_thumbnail_url", true);
					Reset(templateThumbnail, false);
					
					// Set customer
					var customerId = WCXML.GetElementText(xml, "copy_project_customer_id", true);
					var locationId = WCXML.GetElementText(xml, "copy_project_location_id", true);
					//load customer SDrop
					var selector = document.getElementById('selectProjectCustomerId');
					// destroy previous SDrop and reset value
					$(selector).val("");
					if(selector.SDrop){
						selector.SDrop.destroy();
					}
					$(selector).empty();
					
					if(selector){
						var self = this;
						(function(){
							require(["component/sdrop/SDrop", "component/sdrop/dataproviders/CompanyWithLocationsDataProvider"], function(SDrop, CompanyWithLocationsDataProvider){
								new SDrop($(selector), "", 
										// locationid will force the location to be loaded, even if user doesn't have visibility on it
										new CompanyWithLocationsDataProvider ({"locationid": locationId}), { 
									'onChangedByUser': selectCustomer.bind(self, locationId),
									'onInitialized': selectCustomer.bind(self, locationId),
									'initialValue': customerId,
									'manageStyleAndWidth' : false,
							        'autoload': true,
							        'enableEmptySelection': true,
							        'maxMatches': 50
								});
							});
							
						})(locationId, customerId);
						
					}
					
					// Select the project status
					// IL: DT124452 - it makes no sense to copy the project status
					
					// Set project manager
					var projectPMGroupId = WCXML.GetElementText(xml, "copy_project_pm_group_id", true);
					if (projectPMGroupId) {
						$("#selectProjectManagerId option[value='" + projectPMGroupId +"']").prop("selected", true);
					}
					
					// focus first visible form element
					$("#mainTableId input:visible, #mainTableId textarea").not(".hasDatepicker").first().trigger("focus");
				}
			});  // End Ajax code
		} catch (err) {
			alert("Problem in keep session alive: " + err);
		}
	});
}

function parsePotentialUserRoleMembers(possibleUsers)
{
	var resultList = new Array();
	
	for (var u=0; u<possibleUsers.length; u++)
	{
		//parse the XML data for each possible user								
		var possibleUser = possibleUsers[u];
		var possibleUserID = possibleUser.getAttribute("id");
		var lastName = WCXML.GetElementText(possibleUser, "last_name", false);
		var firstName = WCXML.GetElementText(possibleUser, "first_name", false);
		var userName = WCXML.GetElementText(possibleUser, "name", false);
		
		//put the data as an custom Object in the array
		var newUserObj = new Object();
		newUserObj.id = possibleUserID;
		newUserObj.name = WCHTML.getUserNameString(firstName, lastName, userName);
		
		resultList.push(newUserObj);
	}	
	return resultList;
}

function resolveDefaultAssignee(defaultAssignee, groupsList)
{
	// just get the group id based on the group name
	// might be extended by smartnames in the future
	if (defaultAssignee==null || defaultAssignee.length==0)
		return null;
	
	var defAssignUpper = defaultAssignee.toUpperCase();	
	for (var i = 0  ; i < groupsList.length ; i++)
	{
		if (groupsList[i].name == defAssignUpper)
			return groupsList[i].id;
	}
	return null;
}

function parsePotentialGroupRoleMembers(xmlElemsList, sortResult)
{
	var resultList = new Array();
	
	for (var g = 0; g < xmlElemsList.length; g++)
	{
		var group = xmlElemsList[g];
		var groupID = group.getAttribute("id");
		var groupName = WCXML.GetElementText(group, "name", false);
		var isRoleStr = WCXML.GetElementText(group, "is_role", false);
		var isRole = (isRoleStr == "1");
		
		//put the data as an custom Object in the array
		var newGroupObj = new Object();
		newGroupObj.id = groupID;
		newGroupObj.name = groupName;
		newGroupObj.isRole = isRole;
		
		resultList.push(newGroupObj);
	}
	
	if (sortResult) 
	{
		//sort is enabled - apply alphabetical sort on group/role name
		resultList = resultList.sort(function value(a,b) {var aname = a.name.toLowerCase(); var bname = b.name.toLowerCase(); return aname == bname ? 0 : (aname < bname ? -1 : 1);});
		// the follwing is for reasons unknown to mankind not robust in IE6, IE7
		//resultList = resultList.sort(function value(a,b){	a = a.name.toLowerCase(); b = b.name.toLowerCase(); return a == b ? 0 : (a < b ? -1 : 1)});
	}
	
	return resultList;
}


function checkPMSelectValidity(selectListElem)
{
	if (selectListElem)
	{
		//get the selected OPTION index
		var newSelectedIndex = selectListElem.selectedIndex;
		
		//check whether a dummy '---' option was selected		
		if (selectListElem[newSelectedIndex].text == '---')
		{
			//need to return to the previously selected OPTION, as the dummy one is invalid for selection
			var prevIndex = $("#managerSelectIndex").val();
			selectListElem.selectedIndex = prevIndex;
		}
		else
		//just update the 'currently selected OPTION index' value
		{
			$("#managerSelectIndex").val(newSelectedIndex);
		}
	}
}

// Reset the whole page so a new project can be put there
function resetPage() {	
	// General Form Reset
	$("#actionformId")[0].reset();
	
	// reset the display values 
	resetDisplayValues();
	
	// Reset Location
	resetLocation();
	
	resetPMBox();
	
	resetRequestorBox();
	
	resetAttributes();
	
	// Reset Documents Table
	resetDocumentsTable(true);
	
	// Remove all Empty Groups and Project Members
	$("#emptyGroupsTableId tbody").empty();
	clearAllProjectMembers(); // Reset the Members list
	$(".sdrop").trigger("blur"); // remove focus from sdrop elements (so they don't pop open in IE)
	$("#mainTableId > div").not("#projectSelectionRowId").hide();
	$("#selectTemplateRowId, #selectProjectRowId").hide();
	
	// Set the projectID that has been selected
	if(gProjectCreationType != "BlankProject" && gProjectSelectBox) {
		var boxId = "#" + gProjectSelectBox.id + " option[value='" + gProjectID + "']"; // jQuery selector
		$(boxId).prop("selected", true);
	}
	
	if(gProjectCreationType != null && (gProjectCreationType == "TemplateProject" || gProjectCreationType == "CopyProject"
		|| gProjectCreationType == "BlankProject")) {
		// show the drop down box depending on the user's selection			
		showTempProjectDropDownList(gProjectCreationType, null, gProjectID) ;	
	}
	
	// Select Project Creation type in the drop down box. Will have been cleared in the reset()
	selectgProjectCreationType();
	
	// Project Creation Only Starting again!
	gProjectCreationStarted = false;
}

// This function does the hiding and showing of the different sections depending on the
// project creation form
function processProjectCreationFormValues(xml) {

	// Get the Project Creation Form Values
	var gProjectCreationFormXml = xml.getElementsByTagName("project_creation_form");
	if(gProjectCreationFormXml.length > 0) {
		gProjectCreationForm.manager = WCXML.GetElementText(gProjectCreationFormXml[0], "project_manager_show", false);
		gProjectCreationForm.customer = WCXML.GetElementText(gProjectCreationFormXml[0], "customer_show", false);
		gProjectCreationForm.description = WCXML.GetElementText(gProjectCreationFormXml[0], "description_show", false);
		gProjectCreationForm.dueDate = WCXML.GetElementText(gProjectCreationFormXml[0], "due_date_show", false);
		gProjectCreationForm.uploadDoc = WCXML.GetElementText(gProjectCreationFormXml[0], "upload_doc_show", false);
		gProjectCreationForm.bom = WCXML.GetElementText(gProjectCreationFormXml[0], "bom_show", false);
		gProjectCreationForm.replaceGroups = WCXML.GetElementText(gProjectCreationFormXml[0], "replace_groups_show", false);
		gProjectCreationForm.inviteMembers = WCXML.GetElementText(gProjectCreationFormXml[0], "invite_memebers_show", false);
		gProjectCreationForm.setAttributes = WCXML.GetElementText(gProjectCreationFormXml[0], "set_attributes_show", false);
		gProjectCreationForm.setThumbnails = WCXML.GetElementText(gProjectCreationFormXml[0], "set_thumbnails_show", false);
		gProjectCreationForm.planning = WCXML.GetElementText(gProjectCreationFormXml[0], "set_planning_show", false);
		gProjectCreationForm.setStatus = WCXML.GetElementText(gProjectCreationFormXml[0], "set_status_show", false);		
		gProjectCreationForm.defaultPlanning = WCXML.GetElementText(gProjectCreationFormXml[0], "default_planning_method", false);		
	}
	
	if (gBOMEnabled === 0) {
		gProjectCreationForm.bom = "DONT_SHOW" ;
	}
	
	// check whether the project autoname prefix has been set or the counter length >0 
	var projectAutoName = WCXML.GetElementText(xml, "project_autoname", false);
	if ( projectAutoName !=null  && projectAutoName == '1' ) {
		gProjectCreationForm.name = "DONT_SHOW" ;
		$("#projectAutoNameMsg").show();	
	}else{
	 	gProjectCreationForm.name = "SHOW";
	 	$("#projectAutoNameMsg").hide();
	}
	
	var projectNameEdit = WCXML.GetElementText(xml, "project_autoname_editfield", false);
	if ( projectNameEdit  !=null  &&  projectNameEdit== '1' )
		$("#projectNameEditFieldRowId").show();			 	
	else
	 	$("#projectNameEditFieldRowId").hide();
	
	// check the is locked project status setting
	var isLockedProjectStatus = WCXML.GetElementBoolean(xml, "project_status_locked", false);
	if (isLockedProjectStatus) {
		// if locked, hide the project status
		gProjectCreationForm.setStatus = "DONT_SHOW";
	}
	
	// You have: DONT_SHOW, SHOW, REQUIRED
	if(gProjectCreationForm.name == "DONT_SHOW"){
		$("#projectNameRowId").hide();
	} else {
		$("#projectNameRowReqId").show();
		$("#projectNameRowId").show();
	}
	
	// Show/Hide project manager
	if (gProjectCreationForm.manager == "DONT_SHOW"){
		$("#projectManagerRowId").hide();
		$("[name = projectManagerRowVisible]").val("0");
		
	} else{
		$("#projectManagerRowId").show();
		$("[name = projectManagerRowVisible]").val("1");
	}
	
	// Show/hoide project status 
	if(gProjectCreationForm.setStatus == "DONT_SHOW"){
		$("#projectStatusRowId").hide();	
	}
	else {
		$("#projectStatusRowId").show();	
	}
	
	
	if(gProjectCreationForm.customer == "DONT_SHOW")$("#projectCustomerRowId").hide();
	else if(gProjectCreationForm.customer == "REQUIRED") $("#PROJ_CREATION_CUSTOMER").addClass("form-required");
	if(gProjectCreationForm.description == "DONT_SHOW")$("#projectDecriptionRowId").hide();
	else if(gProjectCreationForm.description == "REQUIRED") $("#PROJ_CREATION_DESCRIPTION").addClass("form-required");
	if(gProjectCreationForm.dueDate == "DONT_SHOW")$("#projectDueDateRowId").hide();
	else if(gProjectCreationForm.dueDate == "REQUIRED") $("#PROJ_CREATION_PROJECT_DUE_DATE").addClass("form-required");
	if(gProjectCreationForm.uploadDoc == "DONT_SHOW")$("#mainDocumentDetailsRowId").hide();
	if(gProjectCreationForm.bom == "DONT_SHOW")$("#mainBomDetailsRowId").hide();
	if(gProjectCreationForm.replaceGroups == "DONT_SHOW") {
		$("#replaceGroupsRowId").hide();
		$("#inviteMembersRowId").addClass("add-spacing-top");
	} else if(gProjectCreationForm.replaceGroups == "SHOW"){
		$("#replaceGroupsRowId").show();
	}
	if(gProjectCreationForm.inviteMembers == "DONT_SHOW") {
		$("#inviteMembersRowId").hide();
		$("#RoleManagementHolderTable").addClass("no-margin no-border");
		$("#replaceGroupsRowId").addClass("no-bottom-margin");
	}
	if((gProjectCreationForm.inviteMembers == "DONT_SHOW") && (gProjectCreationForm.replaceGroups == "DONT_SHOW"))$("#mainMembersRowId").hide();
	if(gProjectCreationForm.setAttributes == "DONT_SHOW")$("#mainAttributesRowId").hide();
	if(gProjectCreationForm.setThumbnails == "DONT_SHOW")$("#projectThumbnailRowId").hide();
	if(gProjectCreationForm.planning == "DONT_SHOW")$("#projectPlanningRowId").hide();
		
}

// Function to remove all the project members
function clearAllProjectMembers() {
	$("#InviteMembersSelectDivId").empty();
}

// Selects the project creation type after a reset of the form
function selectgProjectCreationType() {
	if(gProjectCreationType == "TemplateProject") {
		$("#projectTypeSelectId option[value='TemplateProject']").prop("selected", true);
	} else if(gProjectCreationType == "BlankProject") {
		$("#projectTypeSelectId option[value='BlankProject']").prop("selected", true);
	} else if(gProjectCreationType == "CopyProject") {
		$("#projectTypeSelectId option[value='CopyProject']").prop("selected", true);
	}
}

// Reset the Location box and empty it
function resetLocation() {
	$("#selectProjectLocationId option[value!='']").remove();
	$("#selectProjectLocationId").prop("disabled",true);
}

// this function resets the display values to the default value
function resetDisplayValues()
{
	gProjectCreationForm.name = 'REQUIRED';
		gProjectCreationForm.manager ='SHOW';
		gProjectCreationForm.customer = 'SHOW';
		gProjectCreationForm.description = 'SHOW';
		gProjectCreationForm.dueDate = 'SHOW';
		gProjectCreationForm.uploadDoc = 'SHOW';
		gProjectCreationForm.bom = 'SHOW';
		gProjectCreationForm.replaceGroups = 'DONT_SHOW';
		gProjectCreationForm.inviteMembers = 'SHOW';
		gProjectCreationForm.setAttributes = 'DONT_SHOW';
		gProjectCreationForm.setThumbnails = 'SHOW';
		gProjectCreationForm.planning ='DONT_SHOW';
		gProjectCreationForm.setStatus = 'SHOW';
		gProjectCreationForm.defaultPlanning = 'BACKWARD';
}

// Reset the PM Group box and empty it
function resetPMBox() {
	$("#selectProjectManagerId option[value!='me']").remove();
	$("#managerSelectIndex").val('0');
}

// reset the attributes
function resetAttributes() {

	var aCatElem = document.getElementById("projectAttributesBlockId");
	if (aCatElem !=null && aCatElem.ACatObj){
		aCatElem.ACatObj.destroy(true);
		aCatElem.ACatObj.restoreAttributesSection();
		aCatElem.ACatObj = null; 
	}	
}

// reset the attributes
function resetPlanning () {
	gProjectCreationForm.planning = 'DONT_SHOW';
}	


function resetRequestorBox() {
	$("#selectRequestorId option[value!='me']").remove();
}

// Validate the project creation
// This function can be called only from places where it's guaranteed all asynchronous work is already done!
function validateProjectCreationForm(langStrings, uniqueNameCheckObj, debug) {

	if (debug)
		alert('Start project validation form');

	// Validate the project name
	if (gProjectCreationForm.name == "SHOW") {
		if (!validateProjectNameField(debug)) {
			alert(langStrings.invalidProjectName);
			return false;
		}
		
		// Make sure the project name doesn't exist already
		if (!validateProjectNameExistence(debug)) {
			alert(langStrings.duplicateProjectName);
			return false;
		}
	}

	// Check whether the customer is filled out
	if (!validateCustomerField(debug)) {
		alert(langStrings.invalidCustomer);
		return false;
	}

	// validate the description
	if (!validateDescription(debug)) {
		alert(langStrings.invalidDescription);
		return false;
	}
	
	// validate the manager field
	if (!validateManager(debug)) {
		alert(langStrings.invalidManager);
		return false;
	}
	
	// Validate BOM
	if (gProjectCreationForm.bom != 'DONT_SHOW') {
		if (!validateBOMForm(langStrings, uniqueNameCheckObj)) {
			return false;
		}
	}
	
	// validateDocTableX
	if(window.docTableObj){
		var validObj = {
			isTemplate : this.isTemplate,   // support for special behavior in a template (context)
    		errors : [],   // array of error objects containing: 
    					   // 'level', 'element', docRowObj and 'msg' or 'attrLabel' members
    		isOK : function() {   // function returning true if no problem found during validation
    			return (this.errors.length == 0);
    		}, 
    		newDocs: [],
    		newDocsDOMElems: {}
    	};
		window.docTableObj.validateDocTable(validObj);
		if (!validObj.isOK()) {
			return false;
		}
		
		// if gProjectCreationForm exists, check for required field before checking number of documents
		if (gProjectCreationForm && gProjectCreationForm.uploadDoc === 'REQUIRED' && window.docTableObj.getNumberOfRows() == 0) {
			alert(langStrings.selectAtLeastOneDoc);
			return false;
		}
	} else {
		// the old documents table implementation is no more used on Project Creation page!
	}
	
	if (!validateRoles(debug)) {
		alert(langStrings.invalidRolesSelection);
		return false;
	}

	if (gProjectCreationForm.planning != 'DONT_SHOW') {
		if (!validatePlanning(debug)) {
			alert(langStrings.invalidPlanning);
			return false;
		}
		// when you have specified a planning date, make sure it is not in the
		// past
		if (!validatePlanningDateInFuture(debug)) {
			alert(langStrings.invalidPlanning_DateInPast);
			return false;
		}
	}

	/*
	 * There is already validation in templatedate.xsl, but IIRC that does not allow to continue if the duedate is in the past. Also, for any validation
	 * it should be used functions from jquery(since we use jQuery calednar). parseDate function seem to work. 
	 * Something like:  $.datepicker.parseDate("mm/dd/yy", someDate); 
	 */
	// validate due date
	if (gProjectCreationForm.dueDate != 'DONT_SHOW') {
		//tha langStrings is passed, because the message depends on whether the due date is mandatory or not.
		if (!validateDueDate(debug, langStrings)) {			
			return false;
		}
						
		if (!validateDueDateInFuture(debug)) {
			if (!confirm(langStrings.invalidDueDate_DateInPast))
				return false;
		}
	}

	return true;
}

/* Helper functions for project validation form */
function validateProjectNameField(debug) {
	// we always need to validate the project name 
	if (isWhitespace($("#projectNameId")[0].value ))
		return false ;
	else return true ;
}

function validateProjectNameExistence(debug) {
	// Check if the project name already exists
	var projectExists =true ;
	var url = "GetProjectCreationInfo.jsp?action=ProjectNameValidation&projectName="+ encodeURIComponent($("#projectNameId")[0].value);
	try {
		ajax({
			url : url,
			type : "GET",
			data : "xml",
			debug : false,
			synchronous : true, // wait for answer
			onError : function(status) {
				alert("Unable to get project creation info. Server status: "
						+ status);
			},
			onSuccess : function(xml) {
				projectExists = WCXML.GetElementBoolean(xml, "project_exists", false);
			}
		}); // End Ajax code
	} catch (err) {
		alert("Problem in keep session alive: " + err);
	}

	return !projectExists; 
	
}

function validateDescription(debug) 
{
	if (gProjectCreationForm.description == 'REQUIRED') 
	{
		if (debug)
			alert( 'description is required ');
			
		if (isWhitespace($("#projectDescriptionId")[0].value ))
			return false ;
		else return true ;
	}
	else 
		return true ;
}

/**
 * Validate the project manager field. If shown, you need to make a selection.
 * @param debug
 * @returns
 */
function validateManager(debug) 
{
	if (gProjectCreationForm.manager == 'SHOW') 
	{
		if (debug)
			alert( 'manager is shown ');
		// only when a value is entered, we can check whether it exists
		if (document.getElementsByName("selectProjectManager").length > 0){
			if (isWhitespace(document.getElementsByName("selectProjectManager")[0].value ))
				return false ;
			else{
				return true;
			}
		} 	
		else 
			return false ;	
	}
	else 
		return true ;
}

function validateRoles(debug) 
{
	if (gProjectCreationForm.replaceGroups  == 'SHOW') 
	{
		if (debug)
			alert( 'Roles need to be replaced - required  ');
		
		for (var r=0; r<gRolesRequired.length; r++)
		{
			var inputsArray = $('input[name="Role_Assignment_Data_RG' + gRolesRequired[r] + '"]');
			var hasValue = false;
			for (var i=0; i<inputsArray.length; i++)
			{
				if (inputsArray[i].value)
				{
					hasValue = true;
					break;
				}
			}
			if (!hasValue)
				return false;
		}			
	}
	return true ;
}

function validatePlanning(debug) 
{
	// task planning date is required if it is set so in template or "backward" planning is set.
	// ("forward" planning uses as a default current date if no other specified...)
	var planningSelector = $("#projectPlanningId");
	if ((gProjectCreationForm.planning == 'REQUIRED') || (planningSelector.is(":visible") && (planningSelector.length > 0) && (planningSelector[0].value == "backward"))) 
	{
		if (debug)
			alert( 'Planning is required ');
			
		if ($("#longFormat_projectTaskDate")==null)
		 	return true ;
		var dateString = $("#longFormat_projectTaskDate")[0].value ;
   	 	if (isWhitespace(dateString) ) 
   	 		return false ;
  
  		
   	 	return  validateDate(dateString);   	
	}
	return true ;
}

function validateDueDate(debug, langStrings) 
{
	var dateString = $("#longFormat_projectDueDate")[0].value ;
	
	if (gProjectCreationForm.dueDate == 'REQUIRED') 
	{
		if (debug)
			alert( 'due date is required ');		
		
		var isValid = true;
   	 	if (isWhitespace(dateString)) 
   	 		isValid = false ;
  
        if(isValid){
      		var hours = $("#projectDueDatePeriodOfDay")[0] ;
      		if (hours.selectedIndex == 0  )
      			isValid =  false;  
		}
   	 		
   	 	if(isValid) isValid = validateDate(dateString);
   	 	
   	 	if (!isValid) {
   	 		//the due date is mandatory!! - give message to fill the due date correctly
   	 		alert(langStrings.invalidDueDate);
   	 	}
   	 	return isValid;
		
	} else {
		//date might not be required, but if it is entered, it should be still valid
		if (!isWhitespace(dateString)) {
			var isValid = validateDate(dateString);   	 	
	   	 	if (!isValid) {
	   	 		//the due date is not mandatory - give message that the format is wrong
	   	 		alert(langStrings.wrongFormatDueDate);
	   	 	}
	   	 	return isValid;
		}		
	}
	return true;
}

function  validatePlanningDateInFuture(debug)
{

	if ($("#longFormat_projectTaskDate") == null ) // due date fields are not displayed, just return 
		return true ; 
	
		var dateString = $("#projectTaskDate")[0].value ;
	   	if (isWhitespace(dateString))  // when the due date is not filled out, do not try to check whether it is in the past
	 		return true ;
		
	  	if (dateString.length < 9 )  // when the due date is not filled out, do not try to check whether it is in the past
 			return true ;

	  	
	  	
		var year  = dateString.substring(6);
		var month = dateString.substring(0,2);
		var day   = dateString.substring(3,5);
	
		var dueTime = new Date();
		var nowMS = dueTime.getTime();
		dueTime.setFullYear(year);
		dueTime.setMonth(month-1);
		dueTime.setDate(day);

		// Take the hour and minutes also into account for the due date.  
	   	addHourMinutesToDate(dueTime, $("#projectTaskDatePeriodOfDay"));
			  	
		return nowMS <= dueTime.getTime();			
}

// regardless whether the due date is required or not, if we show the due date, then we check whether it is not set in the past. 
// if it is set in the past, we give a warning
function validateDueDateInFuture(debug) 
{
	if ($("#longFormat_projectDueDate") == null ) // due date fields are not displayed, just return 
		return true ; 

	if ($("#longFormat_projectDueDate")[0].value == '' ) // due date fields are not displayed, just return 
		return true ; 
	
	var dateString = $("#projectDueDate")[0].value ; // get the date in unformatted value ( MM/DD/YYYY )
	
	if (dateString!=null )
	{		
		if (dateString.length < 9 )  // when the due date is not filled out, do not try to check whether it is in the past
 			return true ;

		var year  = dateString.substring(6);
		var month = dateString.substring(0,2);
		var day   = dateString.substring(3, 5);
	
		var dueTime = new Date();
		var nowMS = dueTime.getTime();
		dueTime.setFullYear(year);
		dueTime.setMonth(month-1);
		dueTime.setDate(day);
		
		// Take the hour and minutes also into account for the due date.  
	  	addHourMinutesToDate(dueTime, $("#projectDueDatePeriodOfDay"));
		
		var due_date_in_future = nowMS <= dueTime.getTime();
		return due_date_in_future ;
	} 
	
	return true ;
}

/*
 * This method takes a date and a form field which indicates the hours/minutes. 
 * The hours and minutes can be deducted by looking at the selected index.
 * Index being 1 means 30 past midnight, index being 2 means 1 h past midnight etc ...  
 * */
function addHourMinutesToDate(date, periodOfDateForm){
	// Take the hour and minutes also into account for the due date.  
  	if  (periodOfDateForm != null && periodOfDateForm.length> 0 ){
  		var hourIndex = periodOfDateForm[0].selectedIndex;
  		if (hourIndex>0){
  			var minutesTotal = (hourIndex -1) * 30 ; 
  			var minutes = minutesTotal % 60;
  			var hours = (minutesTotal - minutes)/60; 
  			date.setHours(hours, minutes, 0, 0);		
  		} 	  		
  	}	
  	return ;
}

function validateCustomerField(debug) {
		
	if (gProjectCreationForm.customer == 'REQUIRED') 
	{
		if (debug)
			alert( 'customer is required');
			
		if ( $("#selectProjectCustomerId")!=null )
		{
			if ($("#selectProjectCustomerId")[0].selectedIndex == 0)
				return false ;
		}
	}
	return true ;
}


/**
*  loadDocTypeSettings: this function will parse the XML and will build up a dictionary of 
*  doctype settings. The key in the dictionary is the doc type if, the content is an array containing the doc type settings: 
*
*  gDocTypeConfigs[<docTypeID>] = array with the following keys
* 	category_option: option of the category: 
*			0 use none, 
*			2 use default, 
*			1 use project 
*   categoryID: id of the category to be used
*
*	autoname_option: option of the category: 
*			0 use none, 
*			2 use default, 
*			1 use project 
*	Autoname On : true/false whether this doctype uses autoname
*   Autoname Edit Field: true/false whether this doc type has an edit field in the autoname
* 
*  There are other options, but these are for debugging reasons. 
*/ 
function loadDocTypeSettings(xml)
{
	// doc autonaming - load the site settings doctype_autonaming_list
	var docTypeSettings = xml.getElementsByTagName("doctype_autonaming");
	if(docTypeSettings != null && docTypeSettings.length > 0)
	{
		var i = 0 ;
		for (i = 0 ; i< docTypeSettings.length ; i++ )
		{
			var project_id = WCXML.GetElementText(docTypeSettings[i], "projectid", false);
			if (project_id == null || project_id.length==0 )
			{
				var docTypeID = WCXML.GetElementText(docTypeSettings[i], "doctypeid", false) ;
			
				var gDocTypeConfig = new Array();
				
				// load the values
				var docNameEditField = false ;
				var useDocAutoNaming = false;
				var autoNamePrefix = '';
				var autoNameSuffix = '' ;
				var projectDocTypeSetting = WCXML.GetElementText(docTypeSettings[i], "autoname_option", false);
				if (projectDocTypeSetting !=null && projectDocTypeSetting == '2' ) // when autonaming is turned on, look at the specified values 
				{
					autoNamePrefix = WCXML.GetElementText(docTypeSettings[i], "autoname_prefix", false);
					if (autoNamePrefix!=null && autoNamePrefix.length > 0) // set the value to use doc autonaming on 
					{
						useDocAutoNaming = true; 
						autoNameSuffix = WCXML.GetElementText(docTypeSettings[i], "autoname_suffix", false) ; ;  // get the suffix to check whether there is an editable part
						if (autoNameSuffix !=null && autoNameSuffix .length > 0)
						{
							if (autoNameSuffix.toLowerCase().indexOf("editfield" ,0) > -1 )
								docNameEditField = true ;
						}									
					}									
				} 

				var categoryDocTypeOption = WCXML.GetElementText(docTypeSettings[i], "category_option", false);
				var categoryID = '' ;
				if (categoryDocTypeOption !=null && categoryDocTypeOption == '2') 
				{	
					categoryID =  WCXML.GetElementText(docTypeSettings[i], "category_id", false) ; 
					gDocTypeConfigUseCategory = true;
			 	} 
		  	  	gDocTypeConfig['categoryID'] 		= categoryID ;	
		  	  	gDocTypeConfig['Autoname On'] 	= useDocAutoNaming ;	  	  
				gDocTypeConfig['Autoname Edit Field'] = docNameEditField;	  	  
				gDocTypeConfig['categoryID'] 		= categoryID  ;
  	  
				// add the fields for debugging reasons 
				gDocTypeConfig['suffixToUse'] 	= autoNameSuffix ;	  
				gDocTypeConfig['projectDocTypePrefix'] 	= '' ;	  
				gDocTypeConfig['systemDocTypePrefix'] 	= autoNamePrefix;
				gDocTypeConfig['systemDocTypeSuffix'] 	= autoNameSuffix;
				
				gDocTypeConfig['autoname_option'] = projectDocTypeSetting;
				gDocTypeConfig['category_option'] = categoryDocTypeOption;
				
		  	  	gDocTypeConfigs[docTypeID] = gDocTypeConfig ;
			} 							
		}
	}

	// doc autonaming - load the project settings 
	if(docTypeSettings != null && docTypeSettings.length > 0)
	{
		var i = 0 ;
		for (i = 0 ; i< docTypeSettings.length ; i++ )
		{
			var project_id = WCXML.GetElementText(docTypeSettings[i], "projectid", false);
			if (project_id != null && project_id.length > 0 )
			{
				docTypeID = WCXML.GetElementText(docTypeSettings[i], "doctypeid", false) ;
			
				var gDocTypeConfig = new Array();
				
				// load the values
				var docNameEditField = false ;
				var useDocAutoNaming = false;
				var autoNamePrefix = '';
				var autoNameSuffix = ''  ;
				
				var systemDocTypeConfig = gDocTypeConfigs[docTypeID];
				
				var projectDocTypeSetting = WCXML.GetElementText(docTypeSettings[i], "autoname_option", false);
				if (projectDocTypeSetting !=null && projectDocTypeSetting == '2') // system settings 
				{
					// check whether there are system settings
					if (systemDocTypeConfig !=null )
					{
						autoNamePrefix = systemDocTypeConfig['systemDocTypePrefix'];
						autoNameSuffix = systemDocTypeConfig['systemDocTypeSuffix'];
					}									
				}
				else if (projectDocTypeSetting !=null && projectDocTypeSetting == '1' ) 
				{
					autoNamePrefix = WCXML.GetElementText(docTypeSettings[i], "autoname_prefix", false);
					autoNameSuffix = WCXML.GetElementText(docTypeSettings[i], "autoname_suffix", false) ;  // get the suffix to check whether there is an editable part

				} 

				if (autoNamePrefix!=null && autoNamePrefix.length > 0) // set the value to use doc autonaming on 
				{
					useDocAutoNaming = true; 
					if (autoNameSuffix !=null && autoNameSuffix .length > 0)
					{
						if (autoNameSuffix.toLowerCase().indexOf("editfield" ,0) > -1 )
							docNameEditField = true ;
					}									
				}									

				var categoryDocTypeOption = WCXML.GetElementText(docTypeSettings[i], "category_option", false);
				var categoryID = '' ;
				if (categoryDocTypeOption !=null && categoryDocTypeOption== '1') 
				{
					categoryID =  WCXML.GetElementText(docTypeSettings[i], "category_id", false) ; 
					gDocTypeConfigUseCategory = true; 
				}
				else if (categoryDocTypeOption !=null && categoryDocTypeOption== '2') 
				{
					if (systemDocTypeConfig!=null) 
					{	
						categoryID = systemDocTypeConfig['categoryID'];
						gDocTypeConfigUseCategory = true; 
					}
				}
	
		  	  	gDocTypeConfig['Autoname On'] 	= useDocAutoNaming ;	  	  
				gDocTypeConfig['Autoname Edit Field'] = docNameEditField;	  	  
				gDocTypeConfig['categoryID'] 		= categoryID  ;
  	  
				// add the fields for debugging reasons 
				gDocTypeConfig['suffixToUse'] 	= autoNameSuffix ;	  
				gDocTypeConfig['projectDocTypePrefix'] 	= '' ;	  
				gDocTypeConfig['systemDocTypePrefix'] 	= autoNamePrefix;
				
				gDocTypeConfig['autoname_option'] = projectDocTypeSetting;
				gDocTypeConfig['category_option'] = categoryDocTypeOption;
				
		  	  	gDocTypeConfigs[docTypeID] = gDocTypeConfig ;
			} 							
		}
	}					

}

function validateDate(dateString) {
	var date = new Date(dateString);
	if (Object.prototype.toString.call(date) !== "[object Date]")
		return false;
	return !isNaN(date.getTime());
}

function loadBOM(i18nDocUConfLangArr) {
	// Clear block
	var bomBlock = $("#projectBOMBlockId");
	bomBlock.empty();
	// Show loading
	showHourGlass(true);
	// Fetch BOM table
	ajax({
		url : "GetProjectCreationInfo.jsp?action=ProjectBOMHTML&projectID=" + ((gProjectID)? gProjectID : "") + "&copyBOM=" + ((gCopyBOM)? gCopyBOM : ""),
		type : "GET",
		data : "text",
		debug : false,
		timeout : 120000,
		synchronous : false,
		onError : function(status) {
			showHourGlass(false);
			// Show error
			bomBlock.append(i18n['BOM_LOADING_FAILED']);
		},
		onSuccess : function(html) {
			showHourGlass(false);
			
			// Append returned HTML
			bomBlock.append(html);
			
			// Init JS
			initBOM(null, i18nDocUConfLangArr);
			
			// Recreate as it could be that a new template/project is loaded
			aCatOptionsArrBOM = new Array();
			aCatArrBOM = new Array();
		}
	});
}

function showHourGlass(showIt) {
	var hourglassBodyContainer = $('#hourglass');
	if (hourglassBodyContainer) {
		if (showIt) {
			hourglassBodyContainer.show();
		} else {
			hourglassBodyContainer.hide();
		}
	}
}

function readURL(input, targetId) {
    if (input.files && input.files[0]) {
        var reader = new FileReader();

        reader.onload = function (e) {
            $('#'+targetId)
                .attr('src', e.target.result)
                .width(100)
                .height(100);
        };
        reader.readAsDataURL(input.files[0]);
    }
}


