/*
projectbom.js
 */
var gSomethingChanged = false;
var gSubmitting = false;
var gNrOfColumns;
var gBOMDocumentCounter = 0;
var gDeletePosition;
var gBOMTargetFolderActions = [];  // array of default folders to be set when the folders are loaded

/**
 * Initialize BOM feature.
 * @param {Object} data - Documents data.
 * @param {array} i18nDocUConfLangArr - Document Upload Configuration language tags array
 */
window.initBOM = function(data, i18nDocUConfLangArr) {
	
	// make sure hovering in table extra row for attributes works correctly
	$(".projectdetailsbom .ordtable").on("mouseenter mouseleave", "tr.docbom-attributes, tr.with-docbom-attributes", function(e){
		var neighbour;
		if ($(this).is(".docbom-attributes")){
			neighbour = $(this).prev();
		} else {
			neighbour = $(this).next();
		}
		neighbour.toggleClass("hovered-state", e.type === "mouseenter");
	});
	
	require(["component/smartnames/savedsearchcontext/SavedSearchContextInfo",
	         "component/smartnames/savedsearchcontext/ProjectCreationDetailsDynamicSmartNameCollector",
	         "component/smartnames/savedsearchcontext/AttributeCategoryDynamicSmartNameCollector",
	         "attributecategory/DocumentSourceHandler"], 
	         function (SavedSearchContextInfo,
	        		 ProjectCreationDetailsDynamicSmartNameCollector,
	        		 AttributeCategoryDynamicSmartNameCollector,
	        		 DocumentSourceHandler) {
				
		// Convert counts to fractional values
		convertCounts();
		
		// Add Count change listeners
		addChangeEvents();
		
		// set document select options (conforming DocumentsTable.js interface)
		if (data) {
			setHasNewDocumentOption(data.templateDocsNumber > 0);
			setHasLinkSelectDocumentOption(data.projectDocsNumber > 0);
			setHasLinkBrowseDocumentOption(data.hasLinkBrowseDocumentOption);
			setHasCopyDocumentOption(data.hasCopyDocumentOption);
			setHasListDeleteOption(data.hasListDeleteOption);
		}
		
		// conforming ProjectCreation.js and DocumentsTable.js interfaces
		if (data) {
			gTemplateDocumentList = data.templateDocList;
			gTemplateProjectID = data.templateProjectID;
			gUploadProjectID = data.projectID;
			gProjectDocumentList = data.projectDocList;
			gHasTemplateDocuments = (data.templateDocsNumber > 0);
			gTemplateDocsLoaded = true;
		} 
		// else 'gTemplateDocsLoaded' and other global variables are set in ProjectCreation.js in createProject() function
		
		showHideAddDocumentOptions();
		
		// Set delete position of new BOM rows
		if (data) {
			gDeletePosition = data.deletePosition;
		}
		else {
			gDeletePosition = 'right';
		}
		
		// Check if folder column should be shown
		checkShowHideFolderColumnBOM();
		
		// Check if +/- in header should be shown
		checkShowHideBOMAttributes(false);
	    
		// Used to collect the context & "dynamic" values of the SmartNames on the page... (for Saved Search with SmartNames)
		var savedSearchContextInfo = new SavedSearchContextInfo();
		if(data===null) {
			// we are on the project creation page 
			// the context is the template we extended...
			savedSearchContextInfo.setProjectId($("#selectTemplateId").val());
			//  => use the newly entered (temporary) information for the Saved Search Document Source... 
			// add the project details SmartNames (temporary values)
			savedSearchContextInfo.pushCollector(new ProjectCreationDetailsDynamicSmartNameCollector());
			// get the attribute category...
			var ACatObj = $("#projectAttributesBlockId").get(0).ACatObj;
			// add the new values entered in the attribute category...
			if(ACatObj!=null) {
				savedSearchContextInfo.pushCollector(new AttributeCategoryDynamicSmartNameCollector(ACatObj));
			}
		}else{
			savedSearchContextInfo.setProjectId(gUploadProjectID);
		}
		
		// put the green links at the bottom
		if (data) {
			// BOM page in an existing project
			initializeDocumentSourceHandler('documentSourcesBOMTextArea', 'documentSourcesBOMHiddenDiv', 'AddDocumentGreenLinkBOMTd', 'BillOfMaterials', i18nDocUConfLangArr, null, true, savedSearchContextInfo, gUploadProjectID); 
		} else {
			// Bill of materials and Documents sections of Project Creation page share the same 
			// Document Upload Configuration XML stored in 'documentSourcesTextArea'!
			// (it's there even if Documents and/or Bill of materials sections are disabled)
			initializeDocumentSourceHandler('documentSourcesTextArea', 'documentSourcesBOMHiddenDiv', 'AddDocumentGreenLinkBOMTd', 'ProjectCreateBOM', i18nDocUConfLangArr, null, true, savedSearchContextInfo, gUploadProjectID); 
		}
	});
};

function saveBOM() {
	if (gSubmitting) return;

	if (gBOMDocumentCounter > 0) {
		// gather all asynchronous work that has to be done for the BOM and wait until it's done
		var asyncWorkPromises = [];
		for (var docAttIdx = 1; docAttIdx <= gBOMDocumentCounter; docAttIdx++) {
			var bomDocACatObj = document.getElementById("documentDivIdBOM"+ docAttIdx + "Attributes");
			if (bomDocACatObj && bomDocACatObj.ACatObj) {
				asyncWorkPromises.push(bomDocACatObj.ACatObj.whenAllAsyncWorkDone());
			}
		}
		Promise.all(asyncWorkPromises).then(function() {
			doValidateAndSaveBOM();
		});
	} else {
		doValidateAndSaveBOM();
	}
}

// Just a local helper function used only in saveBOM() function above.
function doValidateAndSaveBOM() {
	var processedACatObjs = [];

	if (validateBOMForm(langStrings, null, processedACatObjs)) {
		document.actionform.actionVal.value = 'SaveBOM';
		gSomethingChanged = false;
		gSubmitting = true;
		// validation can still trigger 'onSave' JS Buttons/rules in attribute category so we need to wait for all async work again.
		var asyncWorkAfterValidation = [];
		for (var awIdx = 0; awIdx < processedACatObjs.length; awIdx++) {
			asyncWorkAfterValidation.push(processedACatObjs[awIdx].whenAllAsyncWorkDone());
		}
		Promise.all(asyncWorkAfterValidation).then(function() {
			for (var awIdx = 0; awIdx < processedACatObjs.length; awIdx++) {
				processedACatObjs[awIdx].convertDocReferencesToXML();
			}

			document.actionform.submit();
		})
		.catch(function(reason) {
			// the form not submitted (probably due to validation issue detected) - enable all submit buttons again
			EnableMainButtons(true);
			if (console && console.error) {
				console.error("Exception in asynchronous task: " + reason);
			} else {
				alert("Exception in asynchronous task: " + reason);
			}
		});
	}
}


function validateBOMForm(langStrings, uniqueNameCheckObj, processedACatObjs) {
	// Set documentCounter to BOM counter for validation
	var temp = gDocumentCounter;
	gDocumentCounter = gBOMDocumentCounter;
	var success = validateBOMCounts() && validateBOMAttributes(processedACatObjs) && validateDocuments(langStrings, "BOM", uniqueNameCheckObj, processedACatObjs);
	// Reset documentCounter to BOM counter for validation
	gDocumentCounter = temp;
	return success;
}

// This function can be called only from places where it's guaranteed all asynchronous work is already done!
function validateBOMAttributes(processedACatObjs) {
	if (!processedACatObjs) {
		processedACatObjs = [];
	}
	for (var docAttIdx = 1; docAttIdx <= gBOMDocumentCounter; docAttIdx++) {
		var bomDocACatObj = document.getElementById("documentDivIdBOM"+ docAttIdx + "Attributes");
		if (bomDocACatObj && bomDocACatObj.ACatObj) {
			if (!bomDocACatObj.ACatObj.syncPrepareForSubmit()) {
				// attributes were not validated successfully (alert window was already displayed - just bail out)
				return false;
			}
			if (!bomDocACatObj.ACatObj.isDestroyed) {
				processedACatObjs.push(bomDocACatObj.ACatObj);
			}
		}
	}
	// also check the old BOM documents
	var keepValidating = true;
	$("[id^=BOMDocAttr_]").each(function(idx, elem){
		if(keepValidating && elem.ACatObj){
			if (!elem.ACatObj.syncPrepareForSubmit()) {
				// attributes were not validated successfully (alert window was already displayed - just bail out)
				keepValidating = false;
				return false;
			}
			if (!elem.ACatObj.isDestroyed) {
				processedACatObjs.push(elem.ACatObj);
			}
		}
	});
	return keepValidating;
}

function validateBOMCounts() {
	// Validate all hidden decimal count input fields
	var counts = $("input[type='hidden'][name^='dec_count']");
	for (var i = 0; i < counts.length; i++) {
		var count = counts[i];
		// Not empty
		if (!count.value) {
			alert(i18n['INVALID_COUNT_EMPTY']);
			return false;
		}
		// Valid number
		if (isNaN(count.value)) {
			alert(i18n['INVALID_COUNT']);
			return false;
		}
		// Non negative
		if (count.value < 0) {
			alert(i18n['INVALID_COUNT']);
			return false;
		}
	}
	return true;
}

function addChangeEvents() {
	var fractCounts = $("input[type='text'][name^='count']");
	for ( var i = 0; i < fractCounts.length; i++) {
		addChangeEvent(fractCounts[i]);
	}
}

function addChangeEvent(fractCount) {
	$(fractCount).on("change", function() {
        // Something changed
        gSomethingChanged = true;
        // Check entered value and save decimal value in hidden field
        var decValue = WCHTML.fractionalToDecimal(this.value);
        if (isNaN(decValue)) {
            decValue = '';
            this.value = decValue;
        } else {
            // Show fractional value
            this.value = WCHTML.decimalToFractional(decValue);
        }
        var dec_count = $("input[type='hidden'][name='dec_" + this.name + "']");
        dec_count[0].value = decValue;
    });
}

function convertCounts() {
	var counts = $("input[type='text'][name^='count']");
	for ( var i = 0; i < counts.length; i++) {
		// Get value from corresponding hidden field (Firefox caching bug on 'soft' reload)
		var decVal = $("input[type='hidden'][name='dec_" + counts[i].name + "']").val();
		var v = WCHTML.decimalToFractional(decVal);
		counts[i].value = v;
	}
}

function confirmExit() {
	try {
		// If save button clicked and the form is submitting, we don't want to see the warning
		if (!gSubmitting) {
			// run over all attribute categories on the page and detect if at least one attribute has changed
			var isAttrsChanged = false;
			$('[id^="BOMDocAttr_"]').each(function() {
				if (this.ACatObj && this.ACatObj.attributesChanged === true) isAttrsChanged = true;
			});
			if (gSomethingChanged || isAttrsChanged) {
				return i18n['BOM_PAGE_EXIT'];
			}
		}
	} catch (err) {
		alert("Problem in projdetailsbom.confirmExit() callback method: " + err);
	}
}

function createCategoryOptionsBOM(position, projectID, documentID, docVersionID, categoryID, view, canEditAttributes) {
	// Only create if we have catID and the options were not created before
	if (categoryID && !aCatOptionsArrBOM[position]) {
		
		
		// Define Attribute Categories
		aCatOptionsArrBOM[position] = new Object();
		aCatOptionsArrBOM[position].__canEditAttributes = canEditAttributes;
		aCatOptionsArrBOM[position].ACatObj = "BOMDocAttr_" + position;
		aCatOptionsArrBOM[position].ACatPanel = "BOMDocAttr_" + position;
		aCatOptionsArrBOM[position].readURL = "GetAttributeCategoryXML.jsp?categoryid=" + categoryID + "&view=" + view;
		aCatOptionsArrBOM[position].valuesURL = "GetAttributes.jsp?projectid=" + projectID + "&docverid=" + docVersionID;
		aCatOptionsArrBOM[position].view = view;
		aCatOptionsArrBOM[position].prefix = "BOMDoc_" + position;
		aCatOptionsArrBOM[position].defaultHourAsHalfHours = gDefaultHourAsHalfHours;
		aCatOptionsArrBOM[position].type = "document";
		aCatOptionsArrBOM[position].projectID = projectID;
		aCatOptionsArrBOM[position].documentID = documentID;
		aCatOptionsArrBOM[position].docVersionID = docVersionID;
		aCatOptionsArrBOM[position].docTableParentDocVerIDs = [docVersionID]; // needed for children document tables to check cyclic dependencies!
	}
}

function loadBOMAttributes(position) {	
	if (!aCatArrBOM[position] && aCatOptionsArrBOM[position]) {
		require(["attributecategory/AttributeCategory", "utils/ObjectArrayCloneUtil"], function(AttributeCategory, ObjectHandler){
			
			// User			
			aCatOptionsArrBOM[position].currentUser = ObjectHandler.getCloneOfObject(gCurrentUser);
			aCatOptionsArrBOM[position].currentUser.canEditAttributes = aCatOptionsArrBOM[position].__canEditAttributes;
			
			
			aCatArrBOM[position] = new AttributeCategory(aCatOptionsArrBOM[position]);
		});
	}
}

function showBOMAttributes(position) {
	loadBOMAttributes(position);
	$('#documentAttributesShowIconIdBOM_' + position).hide();
	$('#documentAttributesHideIconIdBOM_' + position).show();
	$('#BOMDocAttrRow_' + position).show();
}

function hideBOMAttributes(position) {
	$('#BOMDocAttrRow_' + position).hide();
	$('#documentAttributesHideIconIdBOM_' + position).hide();
	$('#documentAttributesShowIconIdBOM_' + position).show();
}

function showAllBOMAttributes() {
	// Show the hidden
	$("[id^='documentAttributesShowIconIdBOM']").filter(":visible").trigger("click");
}

function hideAllBOMAttributes() {
	// Hide the shown
	$("[id^='documentAttributesHideIconIdBOM']").filter(":visible").trigger("click");
}

function checkShowHideBOMAttributes(force) {
	var count = $("[id^='documentAttributesShowIconIdBOM']").filter(":visible").length + $("[id^='documentAttributesHideIconIdBOM']").filter(":visible").length;
	// +/- visible
	if (force || count > 0) {
		$("#BOMDocAttrShowHideAll").show();
	}
	else {
		$("#BOMDocAttrShowHideAll").hide();
	}
}

/**
 * Add new documents to the documents table in the Bill of Materials or the BOM section in the Project creation
 * this is a sister function of addRow in DocumentTable.js
 * @param docSourceType - same types as in addRow in DocumentTable.js
 * @param {DOM element} greenLinkElem - DOM element of Document Link (often green) that was clicked by the user.
 * 		It contains Document Link Object (from DocumentSourceHandler.docSources array) defining current doc. source.
 * @param {Object} dlsObj - Document Link Object (from DocumentSourceHandler.docSources array) defining current doc. source. (if known)
 * @param showGridOverride - Only defined when called from DocumentSourceHandler's addSearchResultToDocTable() function.
 *       In project creation, for a document selected from a saved search dialog, the search dialog's "showGrid" hidden input
 *       field shouldn't be taken into account. When set to 1 it upsets the layout in the BOM section of the project creation screen.  
 */
function addBOMRow(docSourceType, greenLinkElem, dlsObj, showGridOverride) {
	try {
		// If we're on the BOM page in Grid layout we need the added row laid out in a different 
		// way from the List layout. Otherwise, the page will look aesthetically very unpleasant.  
		// Various sections of code below utilise the showGrid variable to achieve this.
		var showGrid = null;
		if (showGridOverride !== undefined && showGridOverride !== null) {
			showGrid = showGridOverride; 
		} else {
			showGrid = $('input[name=showGrid]').val();
		}
		if (showGrid == null) {
			showGrid = 0;
		}
		
		var targetFolderName = "";
		var label = "";
		// get the particular Document Link Source, stored in one of the function params
	    if (!dlsObj && greenLinkElem) dlsObj = greenLinkElem.dlsObj;
	    if (dlsObj) {
			//targetFolderName = WCXML.xmlencode(dlsObj.targetFolder);   // HADW CR: Jan, why do encode this???
			//label = WCXML.xmlencode(WCXML.QuoteEncode(dlsObj.label.getLabel()));
			targetFolderName = dlsObj.targetFolder;
			label = dlsObj.label.getLabel();		
	    } 
		
		var startCount = $("#bomtable > tbody[class='savedBOMs'] tr[id^='BOMDocRow']").length;
		var newCount = ($("#bomtable > tbody[class='newBOMs']").children().length - 1) / 2;

		var alt = ((startCount + newCount) % 2 === 1);
		if (showGrid == 1) alt = !alt;
	
		var counter = "BOM" + ++gBOMDocumentCounter;		
		var htmlString = '<tr id="documentRowId' + counter + '" ' + (alt ? 'class="alt"' : '') + '>';
		
			if (showGrid == 1) htmlString += "<td colspan='" + gNrOfColumns + "'><table><tr><td>";
	
				var deleteCell = '<td><a href="#" onclick="javascript:deleteNewBOMEntry(\'documentRowId'+ counter + '\'); return false;"><i class="icon icon-normal icon-WCR_Remove12 btn btn-no-border" title="' + WCXML.xmlencode(langStrings.del) + '"></i></a></td>';
	
				// Delete -
				if (gDeletePosition === 'left') {
					htmlString += deleteCell;
				}
				
				// Attributes +/-
				htmlString += '<td class="td-narrow td-centered"><i id="documentAttributesShowIconId' + counter + '" onclick="showDocumentAttributes(\'' + counter + '\');" class="icon icon-normal icon-WCR_Plus-square" title="' + WCXML.xmlencode(langStrings.expand) + '" style="display: none;"></i><i id="documentAttributesHideIconId' + counter + '" class="icon icon-normal icon-WCR_Minus-square" title="' + WCXML.xmlencode(langStrings.collapse) + '" onclick="hideDocumentAttributes(\'' + counter + '\');" style="display:none"></i></td>';
	
				htmlString += '<td>';
					htmlString +="<div >";
						htmlString +="<div class='bom-new-doc clearfix'>";
							htmlString += "<table class='bom-document-column-new'>";
								htmlString += "<tr>";
									// Source
									htmlString += documentColumnNew(counter, gHasNewDocumentOption, dlsObj.docTemplateType, dlsObj.docTemplateName, docSourceType);
								htmlString += "</tr>"; 
							htmlString+="</table>"; 
							htmlString += '<div class="bom-name-input">';
								htmlString += '<span' + ' id="documentNameLabelId' + counter + '">' + i18n['PROJ_CREATION_NAME'] + ':</span>';
								htmlString+='<div class="bom-form-entry"><input class="form-control" value="" name="documentName' + counter + '" id="documentNameId' + counter + '"/>';
									htmlString += '<input type="hidden" name="documents" value="' + counter + '"/><input type="hidden" name="folderName' + counter + '" id="folderNameId' + counter + '" value=""/>';
									htmlString += '<input type="hidden" name="templateFolderName' + counter + '" id="templateFolderNameId' + counter + '" value=""/>';
								htmlString += '</div>';
							htmlString += '</div>';
						htmlString += '</div>';
						htmlString += "<div>";
							htmlString += "<div>";
								htmlString += '<div class="bom-description-input">';
									htmlString += '<span' + ' id="documentDescriptionLabelId' + counter + '" align="right">' + i18n['DESCRIPTION'] + ':</span>';
									htmlString += '<div class="bom-form-entry"><input  class="form-control" value="" name="documentDescription' + counter + '" id="documentDescriptionId' + counter + '"/></div>';		
								htmlString += "</div>";
							htmlString += "</div>";
						htmlString += '</div>';
					htmlString += "</div>";
				htmlString += "</td>";
	
				// Count
				if (showGrid == 1) htmlString += '<td' + ' class="count-label" id="documentNameLabelId' + counter + '" align="right">' + i18n['COUNT'] + ':';
				htmlString += '<td><input type="text" value="1" name="count' + counter + '" size="7"/><input type="hidden" value="1.0" name="dec_count' + counter + '"/></td>';
	
				// Folder
				htmlString += '<td class="hideShowFolderColumnBOM"><select name="documentFolder' + counter + '" id="documentFolderId' + counter + '" class="filter" onchange="changeDocumentFolder(this, \'' + counter + '\');">' + makeProjectFoldersOptionsString(counter) + '</select><input type="hidden" name="selectedDocumentFolderName' + counter + '" id="selectedDocumentFolderName' + counter + '" value="Default"/></td>';
	
				// Delete -
				if (gDeletePosition === 'right') {
					htmlString += deleteCell;
				}
	
			if (showGrid == 1) htmlString += '</td></tr></table></td>'; 
			if(gNrOfColumns - 5 > 0) {
				htmlString += "<td class='lastCol' colspan='" + (gNrOfColumns - 5) + "'/>";
			}

		htmlString += "</tr>";
		
		// Attributes
		htmlString += '<tr id="documentRowId' + counter + 'Attributes" style="display:none">';
		if (showGrid == 0) {
			htmlString += '<td />';
			if (gDeletePosition === 'left') {
				htmlString += '<td />';
			}
		}

			if (showGrid == 0) { 
				htmlString += '<td id="documentAttrsCellSpanId' + counter + '" colspan="'+ (gNrOfColumns - 2) +'"><div id="documentDivId' + counter + 'Attributes" /></td>';
			} else {
				htmlString += '<td id="documentAttrsCellSpanId' + counter + '" colspan="'+ (gNrOfColumns - 2) +'"><div id="documentDivId' + counter + 'Attributes" /></td>';
			}
		htmlString += '</tr>';	

		
		$("#bomtable > tbody[class='newBOMs']").append(htmlString);
		$("#bomtable > tbody[class='newBOMs']").show();
		
		// store Document Link Source object in the row <tr> element in property 'dlsObj'
		// (note here the counter is prefixed by "BOM" already!)
		var rowIDElem = document.getElementById("documentRowId" + counter);
		if (rowIDElem && dlsObj) rowIDElem.dlsObj = dlsObj;
		
		// Add change event for count
		addChangeEvent($("#bomtable > tbody[class='newBOMs'] input[type='text'][name='count" + counter + "']"));
		
		// Hide column if needed
		checkShowHideFolderColumnBOM();

		// switch to the correct type
		var docSourceTypeValue = "Browse"; // default value
		if (docSourceType === 1)
			docSourceTypeValue = "Copy";
		else if (docSourceType === 2)
			docSourceTypeValue = "New";
		else if (docSourceType === 3)
			docSourceTypeValue = "Select";
		else if (docSourceType === 4)
			docSourceTypeValue = "CreationCopy";
		else if (docSourceType === 5 )
			docSourceTypeValue = "Search" ; 
		else if (docSourceType === 6 )
			docSourceTypeValue = "Move" ; 
		else if (docSourceType === 7 )
			docSourceTypeValue = "Link" ;   // Copy as link
			
		setDocumentType(docSourceTypeValue, counter, label);
		// Specifically used for Browse and Select from Project Fixed Template	
		if ((docSourceType == 0 || docSourceType == 1) && dlsObj.docTemplateType == 'FixedDocTemplate') {
			var templId = $("#documentTemplateId" + counter)[0];
			// If there's been an invalid template name typed in the config page
			// we don't want to attempt to get any attributes
			if (templId) {
				getDocumentAttributes(templId, counter);
			}
		}		
		
		// set the folder selector
		// One problem is the asynch loading of this dropdown via getProjectFoldersOptions
		if (targetFolderName) {		
			if (gProjectFolders) {
				$("#documentFolderIdBOM" + gBOMDocumentCounter + " option").each ( function (index) {
					if (  $(this).text() && $(this).text().toLowerCase() == targetFolderName.toLowerCase()  ) {
						$(this).prop('selected', true);	
						$("#selectedDocumentFolderNameBOM" + gBOMDocumentCounter).val( $(this).text() );  // set hidden field, but only when you find a match						
					}
				});
			} else {
				// dropdown with projects and folders is not yet loaded --> set a global variable to set this folder
				gBOMTargetFolderActions.push({id: 'documentFolderIdBOM' + gBOMDocumentCounter , folder:targetFolderName, hiddenId: 'selectedDocumentFolderNameBOM' + gBOMDocumentCounter} );
			}
		}
		
		gSomethingChanged = true;
	} catch (err) {
		alert('Problem in projdetailsbom.addBomRow at line ' + err.lineNumber + ' : ' + err.message);	
	}
}

// Check whether the folder column should be shown
function isShowFolderColumnBOM() {
	// Hide "Folder" selection column in BOM Table if current project has no folders and no saved BOM entries (standard one tr),  otherwise show the "Folder" column
	return ((gProjectFolders != null && gProjectFolders.length > 1) || $("#bomtable > tbody[class='savedBOMs']").children().length > 1);
}

// Check whether the folder column should be shown and hide if needed
function checkShowHideFolderColumnBOM() {
	// Hide column if needed
	if (isShowFolderColumnBOM()) {
		$(".hideShowFolderColumnBOM").show();
		$("td[id^='documentAttrsCellSpanIdBOM']").attr('colspan', (gNrOfColumns - 2));
	}
	else {
		$(".hideShowFolderColumnBOM").hide();
		$("td[id^='documentAttrsCellSpanIdBOM']").attr('colspan', (gNrOfColumns - 3));
	}
}

// Delete newBOM row
function deleteNewBOMEntry(rowId) {
	deleteEntry(rowId);
	
	// Re-alternate
	alternateNewBOMs();

	// Check if +/- should be shown in header
	checkShowHideBOMAttributes(false);
}

function alternateNewBOMs() {
	// Re-alternate new BOM rows
	var startCount = $("#bomtable > tbody[class='savedBOMs'] tr[id^='BOMDocRow']").length;
	var lastAlt = ((startCount % 2) === 0);
	var newBOMs = $("#bomtable > tbody[class='newBOMs']").children();
	for ( var i = 0; i < newBOMs.length; i++) {
		var newBOM = $(newBOMs[i]);
		if (newBOM.attr("id") && newBOM.attr("id").indexOf("Attributes") === -1) { // New BOM row (no attributes)
			lastAlt = !lastAlt; // alt needed
			newBOM.attr("class", (lastAlt ? "alt" : ""));
		}
		else {
			newBOM.attr("class", "");
		}
	}
}

// Delete saved BOM entry
function deleteSavedBOMEntry(position) {
	$("#BOMDocAttrRow_" + position).remove();
	$("#BOMDocAttrRowImgMsg_" + position).remove();
	$("#BOMDocRow_" + position).remove();
	
	var html = '<input type="hidden" name="excludeFromBOM" value="' + position + '"/>';
	$("#bomtable > tbody[class='savedBOMs']").append(html);
	
	// Re-alternate
	alternateSavedBOMs();
	
	// Re-alternate
	alternateNewBOMs();
	
	// Check if +/- should be shown in header
	checkShowHideBOMAttributes(false);
	
	// Check if column should still be visible
	checkShowHideFolderColumnBOM();
}

function alternateSavedBOMs() {
	// Re-alternate saved BOM rows
	var savedBOMs = $("#bomtable > tbody[class='savedBOMs']").children();
	var lastAlt = true;
	for ( var i = 0; i < savedBOMs.length; i++) {
		var savedBOM = $(savedBOMs[i]);
		if (savedBOM.attr("id") && savedBOM.attr("id").indexOf("Attr") === -1) { // BOM row (no attributes)
			lastAlt = !lastAlt; // alt needed
			savedBOM.attr("class", (lastAlt ? "alt" : ""));
		}
		else {
			savedBOM.attr("class", "");
		}
	}
}


