<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xsl:stylesheet [
  <!ENTITY copy "&#169;">
  <!ENTITY nbsp "&#160;">
  <!ENTITY lk "/webcenter_page/user_lang_key">
]>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:Lang="com.esko.webcenter.jsp.LanguageMgr" exclude-result-prefixes="Lang">

<xsl:import href="pagingtemplate.xsl"/>
<xsl:import href="templatedate.xsl"/>
<xsl:import href="projectstatusestemplates.xsl"/>

	<!-- global variables -->
	<xsl:variable name="isTemplate" select="/webcenter_page/project/is_template"/>
	<xsl:variable name="isProjectActive" select="key('projectStatusKey',/webcenter_page/project/status_id)/is_active"/>
	<xsl:variable name="headerSmallMarginBottom" select="false()" />
   	<xsl:variable name="wizard"><xsl:call-template name="isWizardPage"/></xsl:variable>

  <!-- 
  
            template that controls the generation of the menus and doc header (thumbnail, description, ...)
            
  -->
  <xsl:template name="header">
	<!--
	  Search Results paging uses a different form than the rest of the page for historical reasons.
	  The next/previous links which use this form are located on a different form but that is not a problem.
	  It is important thing is that this form not become nested inside of the page's main form.
	-->
	<form name="detailslinksform" method="post" action="projdetails.jsp"> 
	  <input type="hidden" name="projectSearchIndex" value=""/>
	</form>
    
    <form name="projactionform" method="post" action="doprojectactions.jsp">
      <input type="hidden" name="actionVal" value=""/>
      <input type="hidden" name="changeStatus" value="0"/>
      <input type="hidden" name="sourcePage_primaryChoice" />
      
      <!-- The source page input gets used after functions like add to cart to redirect you back here. -->
      <input type="hidden" name="sourcePage">
      <xsl:choose>
        <xsl:when test="proj_search_index &gt; 0">
          <xsl:attribute name="value">projdetails.jsp?searchProjectID=<xsl:value-of select="project/@id"/>&amp;projectSearchIndex=<xsl:value-of select="proj_search_index"/>&amp;<xsl:call-template name="menuFileUrlParameter"/></xsl:attribute>
        </xsl:when>
        <xsl:otherwise>
          <xsl:attribute name="value">projdetails.jsp?projectID=<xsl:value-of select="project/@id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/></xsl:attribute>
        </xsl:otherwise>
      </xsl:choose>
      </input>
      
      <xsl:call-template name="projDetailsHiddenInputs"/>
	  
	  <!-- add selected folder ID for redirection purposes -->
	  <input type="hidden" name="selectedFolderID" value="{selected_folder_id}"/>
	  
	  <!-- add selected folder ID for redirection purposes -->
	  <input type="hidden" name="categoryID" value="{/webcenter_page/project/category_id}"/>
	  
	  <!-- Display project details header -->
      <xsl:call-template name="newDisplayProjDetailsHeader"/>
    </form>
  </xsl:template>
  
  <!-- 
		Template for page specific header actions  
   -->
  <xsl:template name="projectDetailsHeaderActions">
  </xsl:template>
  
  <!-- 
  		Template for configurable header actions
   -->
  <xsl:template name="projectDetailsConfigurableHeaderActions">
	<xsl:param name="actionMenuName"/>

	<xsl:variable name="isAdmin" select="/webcenter_page/is_admin"/>
	<xsl:variable name="isPM" select="/webcenter_page/is_manager"/>
	<xsl:variable name="isPC" select="/webcenter_page/is_project_creator "/>
	<xsl:variable name="isTemplate" select="/webcenter_page/project/is_template &gt; 0"/>
	<xsl:variable name="isFavorite" select="/webcenter_page/project/is_in_my_favorites &gt; 0"/>
	
	<!-- Add multiple documents: for admin, PM or users with add rights -->
	<xsl:variable name="isProjectEditable" select="/webcenter_page/is_project_editable"/>
	<xsl:variable name="selectedFolder" select="/webcenter_page/selected_folder_id"/>
	<xsl:variable name="userHasAddRights">
		<xsl:choose>
			<!-- admin and PM can always add documents -->
			<xsl:when test="$isAdmin or ($isProjectEditable = '1')">
				<xsl:value-of select="'1'"/>
			</xsl:when>
			<!-- when the project is not active, you cannot add a document -->
			<xsl:when test="($isProjectActive = '0')">
				<xsl:value-of select="'0'"></xsl:value-of>
			</xsl:when>
			<!-- check whether we are looking at the project root or at the folder  -->
			<!-- root is selected, check the project permissions -->
			<xsl:when test=" string-length($selectedFolder) = 0 ">
				<xsl:value-of select="/webcenter_page/project_user_permissions/permission/add"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="/webcenter_page/folder_user_permission_list/folder_user_permission[folder_id=$selectedFolder]/permission/add"/>
			</xsl:otherwise> 
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="userHasDownloadRights">
		<xsl:choose>
			<!-- admin and PM can always add documents -->
			<xsl:when test="$isAdmin or ($isProjectEditable = '1')">
				<xsl:value-of select="'1'"/>
			</xsl:when>
			<!-- JAMI: according to spec, downloading a document is allowed even for inactive projects -->
			<!-- when the project is not active, you cannot download a document -->
			<!-- xsl:when test="($isProjectActive = '0')">
				<xsl:value-of select="'0'"></xsl:value-of>
			</xsl:when-->
			<!-- check whether we are looking at the project root or at the folder  -->
			<!-- root is selected, check the project permissions -->
			<xsl:when test=" string-length($selectedFolder) = 0 ">
				<xsl:value-of select="/webcenter_page/project_user_permissions/permission/download"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="/webcenter_page/folder_user_permission_list/folder_user_permission[folder_id=$selectedFolder]/permission/download"/>
			</xsl:otherwise> 
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="userHasCreateChildRights">
		<xsl:choose>
			<!-- admin and PM can always add child projects -->
			<xsl:when test="$isAdmin or ($isProjectEditable = '1')">
				<xsl:value-of select="'1'"/>
			</xsl:when>
			<!-- check the change properties permissions and if the user is a PM (user role, not project) -->
			<xsl:when test="$isPM or $isPC">
				<xsl:value-of select="/webcenter_page/project_user_permissions/permission/update"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="'0'"/>
			</xsl:otherwise> 
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="userHasLinkInExistingRights">
		<xsl:choose>
			<!-- admin and PM can always link in child projects -->
			<xsl:when test="$isAdmin or ($isProjectEditable = '1')">
				<xsl:value-of select="'1'"/>
			</xsl:when>
			<!-- check the change properties permissions -->
			<xsl:otherwise>
				<xsl:value-of select="/webcenter_page/project_user_permissions/permission/update"/>
			</xsl:otherwise> 
		</xsl:choose>
	</xsl:variable>
	<xsl:variable name="hasTaskManagementLicense" select="count(/webcenter_page/has_task_management_license) > 0" />
	<xsl:variable name="canChangeTask">
		<xsl:choose>
			<!-- no License -->
			<xsl:when test="not($hasTaskManagementLicense)">
				<xsl:value-of select="'0'"/>
			</xsl:when>
			<!-- admin and PM can always add documents -->
			<xsl:when test="$isAdmin or ($isProjectEditable = '1')">
				<xsl:value-of select="'1'"/>
			</xsl:when>
			<!-- when the project is not active, only PM and Admin can create tasks -->
			<xsl:when test="($isProjectActive = '0')">
				<xsl:value-of select="'0'"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="/webcenter_page/project_user_permissions/permission/change_task"/>
			</xsl:otherwise> 
		</xsl:choose>
	</xsl:variable>
	
	<!-- Buttons -->
	<xsl:if test="$wizard = 'false'">
		<xsl:for-each select="key('menuItemKey', $actionMenuName)/menuitem">
			<xsl:if test="$userHasAddRights = '1'">

				<!-- UPLOAD -->
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_UPLOAD'"/>
					<xsl:with-param name="href" select="'javascript:PerformProjectAction(13)'"/>
				</xsl:call-template>
			
				<!--  UPLOAD APPLET -->
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_UPLOADMULTIPLE'"/>
					<xsl:with-param name="href" select="'javascript:PerformProjectAction(14)'"/>
				</xsl:call-template>

				<!-- Copy/Create Multiple New Documents-->
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_COPYCREATE'"/>
					<xsl:with-param name="href" select="'javascript:PerformProjectAction(18)'"/>
				</xsl:call-template>
				
			</xsl:if>
		
			<!-- MAIL TO -->						
			<xsl:call-template name="builtinaction">
				<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_MAILLINK'"/>
				<xsl:with-param name="href" select="'javascript:PerformProjectAction(1)'"/>
			</xsl:call-template>
	
			<!-- SHOW HISTORY -->
			<xsl:call-template name="builtinaction">
				<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_HISTORY'"/>
				<xsl:with-param name="href" select="'javascript:PerformProjectAction(8)'"/>
			</xsl:call-template>
		
			<!-- SEARCH -->
			<xsl:call-template name="builtinaction">
				<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_SEARCH'"/>
				<xsl:with-param name="href" select="'javascript:PerformProjectAction(10)'"/>
			</xsl:call-template>
				
			<!-- DOWNLOAD -->
			<xsl:if test="$userHasDownloadRights = '1'">
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_DOWNLOAD'"/>
					<xsl:with-param name="href" select="'javascript:PerformProjectAction(15)'"/>
				</xsl:call-template>
			</xsl:if>
			<xsl:if test="not($isTemplate)">
				<!-- Add to Cart -->
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_ADDTOCART'"/>
					<xsl:with-param name="href" select="'javascript:PerformProjectAction(2)'"/>
				</xsl:call-template>
					
					
					
				<xsl:choose>
					<xsl:when test="$isFavorite">
						<!-- Remove from Favorites -->
						<xsl:call-template name="builtinaction">
							<xsl:with-param name="name" select="'PROJECTS_HEADER_ACTION_REMOVEFROMFAVORITES'"/>
							<xsl:with-param name="href" select="'javascript:PerformProjectAction(3,true)'"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<!-- Add to Favorites -->
						<xsl:call-template name="builtinaction">
							<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_ADDTOFAVORITES'"/>
							<xsl:with-param name="href" select="'javascript:PerformProjectAction(3,false)'"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
			
			<!-- Save as template -->
			<xsl:if test="$isAdmin">
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_SAVEASTMPLT'"/>
					<xsl:with-param name="href" select="'javascript:PerformProjectAction(5)'"/>
				</xsl:call-template>
			</xsl:if>
			
			<!-- Update: when the project is active and when the user is PM or Admin -->
			<xsl:if test="($isProjectEditable = '1') and ($isProjectActive = '1')">
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_UPDATE'"/>
					<xsl:with-param name="href" select="'javascript:PerformProjectAction(4)'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="($userHasCreateChildRights = '1') and not($isTemplate)">
				<!-- Create Child Project -->
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_CREATE_CHILD'"/>
					<xsl:with-param name="href">
						<xsl:value-of select="'projmgmntnewproject.jsp?createchild=1&amp;srcprojectid='"/><xsl:value-of select="/webcenter_page/project/@id"/><xsl:value-of select="'&amp;menu_file='"/><xsl:value-of select="/webcenter_page/menu_file"/>
						<xsl:if test="action/actiontype/builtin/project_template">
							<xsl:choose>
								<xsl:when test="action/actiontype/builtin/project_template =''">
									<xsl:value-of select="'&amp;showtemplatesonly=1'"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="'&amp;template='"/><xsl:value-of select="action/actiontype/builtin/project_template"/>
								</xsl:otherwise>
							</xsl:choose>
							
						</xsl:if>
						<xsl:if test="action/actiontype/builtin/project_charpath">
							<xsl:value-of select="'&amp;templatecharacteristicpath='"/><xsl:value-of select="action/actiontype/builtin/project_charpath"/>
						</xsl:if>						
					</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="($userHasLinkInExistingRights = '1') and not($isTemplate)">

				<!-- LINK EXISTING -->
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_LINK_IN_EXISTING'"/>
					<xsl:with-param name="href">
						<xsl:variable name="savedSearchName">
							<xsl:variable name="savedsearchID" select= "action/actiontype/builtin/project_saved_search"/>
							<xsl:value-of select="/webcenter_page/global_saved_search_list/saved_search[@id = $savedsearchID]/name"/>
						</xsl:variable>
						<xsl:text>javascript:PerformProjectAction(19,&quot;</xsl:text><xsl:value-of select="$savedSearchName"/><xsl:text>&quot;)</xsl:text>
					</xsl:with-param>
				</xsl:call-template>
				
				<!-- Make sure the projectSavedSearchDialog is ready to be loaded -->
				<xsl:if test="action/actiontype/builtin/builtin_name='PROJECT_HEADER_ACTION_LINK_IN_EXISTING'">
					<div id="savedSearchDia" data-init="component/savedsearchdialog/ProjectSavedSearchDialog" data-init-priority="-200" style="height: 100%; width: 100%">
			 				
			 				<xsl:attribute name="projectID"><xsl:value-of select="/webcenter_page/project/@id"/></xsl:attribute>
			 				<xsl:attribute name="LinkInExisting">true</xsl:attribute> 
			 		</div>
				</xsl:if>
			</xsl:if>

			<!-- when the user is PM or admin, you can create a new project based on the current one -->
			<xsl:if test="($isProjectEditable = '1')">
				<!-- Copy Project -->
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_COPY'"/>
					<xsl:with-param name="href" select="'javascript:PerformProjectAction(16)'"/>
				</xsl:call-template>

				<!-- Delete Project -->
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_DELETE'"/>
					<xsl:with-param name="href" select="'javascript:PerformProjectAction(11)'"/>
				</xsl:call-template>
				
				<!-- Create Sibling -->
				<xsl:if test="not($isTemplate)">
					<xsl:call-template name="builtinaction">
						<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_CREATE_SIBLING'"/>
						<xsl:with-param name="href" select="'javascript:PerformProjectAction(20)'"/>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>
			
			<!-- Run project report -->
			<xsl:if test="/webcenter_page/has_project_report = '1' and not($isTemplate)">
				<xsl:call-template name="builtinaction">
					<xsl:with-param name="name" select="'PROJECT_HEADER_ACTION_REPORT'"/>
					<xsl:with-param name="href" select="'javascript:PerformProjectAction(17)'"/>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="$canChangeTask = '1'">
				<!-- Create Task -->
				<xsl:call-template name="createtaskaction">
					<xsl:with-param name="projectId" select="/webcenter_page/project/@id"/>
				</xsl:call-template>
					
				<!-- Start Workflow -->
				<xsl:call-template name="startworkflowaction">
			 		<xsl:with-param name="itemidsel" select="'docversionid'"/>
			 		<xsl:with-param name="itemidname" select="'docversionid'"/>
					<xsl:with-param name="projectId" select="/webcenter_page/project/@id"/>
				</xsl:call-template>
			</xsl:if>
				
			<!-- JavaScript -->
			<xsl:call-template name="javascriptaction">
		 		<xsl:with-param name="itemidsel" select="'docversionid'"/>
				<xsl:with-param name="projectId" select="/webcenter_page/project/@id"/>
			</xsl:call-template>
			
			
		</xsl:for-each>

		<!-- additional items for the More actions dropdown from the menu system -->
		<xsl:variable name="menuitemname" select="'PROJ_DETAILS_ACTIONS'"/>
		<xsl:variable name="menu" select="/webcenter_page/nav/menus/menuitem[name=$menuitemname]"/>
		<xsl:for-each select="$menu/menuitem">
			<xsl:variable name="scriptpart">
				<xsl:call-template name="substMenuSmartname">
					<xsl:with-param name="pattern" select="javascript"/>
				</xsl:call-template>
			</xsl:variable>
			<a class="action"
				href="javascript:{$scriptpart}"><xsl:call-template name="getMenuLabel"/></a>
		</xsl:for-each>
	</xsl:if>

  </xsl:template>
  
  <!-- 
  		Template that generates the project header
   -->
  <xsl:template name="newDisplayProjDetailsHeader">
  	<xsl:variable name="isTemplate" select="/webcenter_page/project/is_template &gt; 0"/>
   	<xsl:variable name="isInFavorites" select="/webcenter_page/project/is_in_my_favorites &gt; 0"/>
	<xsl:variable name="isNameLink"><xsl:call-template name="isNameLink"/></xsl:variable>

	<div class="page-header details-header with-menu projectHeader">
		<xsl:if test="$headerSmallMarginBottom">
			<xsl:attribute name="class">page-header details-header with-menu projectHeader small-spacing-bottom</xsl:attribute>
		</xsl:if>		
			<!--  Project Name -->
			<h1>			
				<!-- show header actions (if needed, this will change for configurable actions) -->
				<xsl:call-template name="projectDetailsHeaderActions"></xsl:call-template>
				
				<!--  Header actions are configured -->
				<xsl:if test="true()">
					<div class="action-menu-component header-action-buttons" data-init="component/actionmenu/HeaderActionMenu">
						<xsl:call-template name="projectDetailsConfigurableHeaderActions">
							<xsl:with-param name="actionMenuName" select="'PROJECT_HEADER_TOP_ACTIONS'"/>
						</xsl:call-template>
					</div>
				</xsl:if>
				
				<xsl:if test="$isNameLink = 'true' and ($wizard = 'false')">
					<xsl:variable name="isInSearchResults" select="proj_search_index &gt; 0"/>
					<xsl:if test="$isInSearchResults">	
						<xsl:call-template name="DisplayDetailsPaging">
							<xsl:with-param name="searchIndex" select="/webcenter_page/proj_search_index"/>
							<xsl:with-param name="totItemCnt" select="/webcenter_page/proj_search_total_cnt"/>
							<xsl:with-param name="Name" select="Lang:getStr(&lk;,'PROJECT')"/>
							<xsl:with-param name="Type" select="'project'"/>
						</xsl:call-template>						
					</xsl:if>
				</xsl:if>
				
				<a class="btn btn-no-border details-section-toggle" data-toggle="collapse" data-target=".page-header .details-section"><i class="icon icon-mobile icon-WCR_Info2"></i></a> 		
				<xsl:if test="$isTemplate">
					<xsl:value-of select="Lang:getStr(&lk;,'TEMPLATE')"/>
				</xsl:if>
		  		<xsl:if test="not($isTemplate)">
					<xsl:value-of select="Lang:getStr(&lk;,'PROJECT')"/>
				</xsl:if>:&nbsp;
				
				<xsl:choose>
					<xsl:when test="$isNameLink = 'true'">
						<a class="project-name-link">
 					  		<xsl:call-template name="projectDetailsHref">
								<xsl:with-param name="projectID" select="project/@id"/>
					  		</xsl:call-template>
					  		<xsl:value-of select="project/name"/>
						</a>										
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="project/name"/>
					</xsl:otherwise>
				</xsl:choose>
				
				<!-- Project in Cart indication -->
				<xsl:if test="is_in_cart and $isNameLink = 'true'">&nbsp;
			  		<a href="cartmgr.jsp" title="{Lang:getStr(&lk;,'PROJ_IN_CART')}" class="btn btn-no-border header-align-middle">
			  			<i class="icon icon-WCR_Menu-Cart" />
			  		</a>
		  		</xsl:if>
		  		
		  		<!-- when it is a connection project, show the connection icon -->
				<xsl:if test="(/webcenter_page/project_workflow /allow_manual_sync = '1') and  (/webcenter_page/is_project_editable = '1') and not($isTemplate)"> 
					<a class="btn btn-no-border header-align-middle" title="{Lang:getStr(&lk;,'PROJDETAILS_SYNC_WITH_AE')}">
						<xsl:attribute name="href">
							<xsl:value-of select="'doprojectexporttoAE.jsp?projectID='"/><xsl:value-of select="project/@id"/>&amp;menu_file=<xsl:value-of select="/webcenter_page/menu_file"/>
						</xsl:attribute>
						<i class="icon containerIcon  icon-normal icon-WCR_AE-Sync-cont">
							<i class="icon subIcon icon-normal icon-WCR_AE-Sync-sub"></i>							
						</i>					
				  	</a>
				</xsl:if>
				
				<!-- Project in Favorites indication -->
				<xsl:if test="$isInFavorites and $isNameLink = 'true'">
					<a href="myfavoriteproj.jsp" class="btn btn-no-border header-align-middle">
						<i class="icon-normal icon icon-WCR_Favorite" title="{Lang:getStr(&lk;,'PROJ_IN_FAV')}" />
				  	</a>
				</xsl:if>
				
				<!-- PROJECT STATUS -->
				<!--  Project Status -->
				<!--  The status is not shown for templates -->
				<xsl:if test="not ( $isTemplate)">
					<xsl:call-template name="ProjectStatusLabel">
						<xsl:with-param name="selectedProjectStatusId" select="project/status_id"/>
						<xsl:with-param name="isEditable" select="(/webcenter_page/is_project_status_editable = '1') and ($isNameLink = 'true') and ($wizard = 'false')" />
						<xsl:with-param name="langKey" select="key('projectStatusKey', project/status_id)/translation_tag"/>
						<xsl:with-param name="alternativeLabel" select="key('projectStatusKey', project/status_id)/status_name"/>
						<xsl:with-param name="statusColor" select="key('projectStatusKey', project/status_id)/color_rgb"/>
						<xsl:with-param name="displaySelectedIgnoreDeleted" select="true()" />
						<xsl:with-param name="projectStatusElementID">projectStatusIndicator</xsl:with-param>
					</xsl:call-template>
					
									
							
					<!-- when a project is not a template and when it is not active, show the warning message that the project is non-active -->
					<xsl:choose>							
						<xsl:when test="key('projectStatusKey', /webcenter_page/project/status_id)/is_deleted = '1'">
							<small class="header-align-middle"><span class="label label-danger">							
								<xsl:value-of select="Lang:getStr(&lk;, 'DELETED_TAG')"/>
							</span></small>									
						</xsl:when>
						<xsl:otherwise>
							<xsl:if test=" ($isProjectActive = '0')">
								<small class="header-align-middle"><span class="label label-danger">		
									<xsl:value-of select="Lang:getStr(&lk;, key('projectStatusKey', /webcenter_page/project/status_id)/status_type)"/>
								</span></small>		
							</xsl:if>								
						</xsl:otherwise>
					</xsl:choose>
			
				</xsl:if>
			</h1>
			<div class="details-section collapse">
				<div class="details-static">
					<div class="details-section-content">
						<!-- always visible section -->
						<div class="details-action-buttons action-menu-component vertical" data-max-items="4" data-init="component/actionmenu/VerticalActionMenu" data-init-priority="100">
							<xsl:call-template name="projectDetailsConfigurableHeaderActions">
								<xsl:with-param name="actionMenuName" select="'PROJECT_HEADER_LEFT_ACTIONS'"/>
							</xsl:call-template>
						</div>
						
						<div class="details-thumbnail">
							<img src="{project/thumbnail_url}" width="100" height="100" />
						</div>
						
					</div>
				</div>
				<div class="details-overflow">
					<div class="details-section-content">
						<div class="project-info">
							<table class="projectInfo">
								<tr>
									<!--  Manager -->
									<td class="td-label"><xsl:value-of select="Lang:getStr(&lk;,'MANAGER')"/>:</td>
									<td>
										<xsl:variable name="isUserPM" select="project/manager/manager_type = 'user'"/>
										<xsl:choose>
											<xsl:when test="$isUserPM">
												<xsl:call-template name="DisplayUserName">
													<xsl:with-param name="userID" select="project/manager_id"/>
													<xsl:with-param name="projectID" select="project/@id"/>
													<xsl:with-param name="lastName" select="project/manager/last_name"/>
													<xsl:with-param name="firstName" select="project/manager/first_name"/>
													<xsl:with-param name="loginName" select="project/manager/name"/>
													<xsl:with-param name="isActive" select="project/manager/is_active"/>
												</xsl:call-template>
											</xsl:when>
											<xsl:otherwise>
												<xsl:call-template name="DisplayGroupName">
													<xsl:with-param name="groupID" select="project/manager_id"/>
													<xsl:with-param name="groupName" select="project/manager/group/name"/>
													<xsl:with-param name="isRole" select="project/manager/group/is_role"/>
													<xsl:with-param name="projectID" select="project/@id"/>				
													<!-- don't display the group/role tag -->
													<xsl:with-param name="displayIcon" select="'-1'"/>	
												</xsl:call-template>
											</xsl:otherwise>
										</xsl:choose>
									</td>
									
									<!--  Project attributes -->
									<td rowspan="4" class="header-attributes-cell">
										<div id="projectHeaderAttributesId" class="header-attributes">
										<xsl:if test="(/webcenter_page/project/category_id) and (/webcenter_page/category/layout_empty = 0)">
											<xsl:attribute name="data-init">pages/attributes/ProjectHeaderAttributes</xsl:attribute>
											<xsl:attribute name="data-init-priority">500</xsl:attribute>
											<xsl:attribute name="data-projectid"><xsl:value-of select="project/@id" /></xsl:attribute>
											<xsl:attribute name="data-categoryid"><xsl:value-of select="project/category_id" />&amp;view=Header</xsl:attribute>
											<xsl:attribute name="data-lastmodified"><xsl:value-of select="/webcenter_page/category/mod_time_stamp" /></xsl:attribute>			
										</xsl:if>
										</div>
									</td>
								</tr>
								<!--  Customer -->
								<tr>
									<td class="td-label"><xsl:value-of select="Lang:getStr(&lk;,'CUSTOMER')"/>:</td>
									<td><xsl:call-template name="DisplayCustomer"/></td>
								</tr>
								<!--  Due Date -->
								<tr> <!-- keep tr for templates also to avoid layout problems with 4-row attribute header views -->
									<xsl:if test="not($isTemplate)">
										<td class="td-label"><xsl:value-of select="Lang:getStr(&lk;,'DATEDUE')"/>:</td>
										<td>
											<table border="0" cellspacing="0" cellpadding="0">
												<tr>
													<td class="Black_11" style="padding: 0px;">
														<xsl:call-template name="HumanReadableShortDate">
															<xsl:with-param name="DateString" select="project/due_date"/>
														</xsl:call-template>
													</td>
													<xsl:if test="project/is_task_overdue = '1'">
														<td class="Black_11" style="padding: 0px;">
															<xsl:choose>
																<xsl:when test="$isNameLink = 'true'">
																	<a href="javascript:OpenTasks();"><i class="icon icon-WCR_Msg-Warning" title="{Lang:getStr(&lk;,'PROJ_IS_OVERDUE')}"></i>	
																	</a>
																</xsl:when>
																<xsl:otherwise>
																	<i class="icon icon-WCR_Msg-Warning" title="{Lang:getStr(&lk;,'PROJ_IS_OVERDUE')}"></i>	
																</xsl:otherwise>
															</xsl:choose>																				
														</td>
													</xsl:if>	
												</tr>
											</table>
										</td>
									</xsl:if>
								</tr>
								<!--  Modified Date -->
								<tr>
									<td class="td-label"><xsl:value-of select="Lang:getStr(&lk;,'DATEMODIFIED')"/>:</td>
									<td>
										<xsl:call-template name="HumanReadableShortDate">
											<xsl:with-param name="DateString" select="project/modified_date"/>
										</xsl:call-template>
									</td>
								</tr>
								<!--  Description -->
								<tr>
									<td class="td-label"><xsl:value-of select="Lang:getStr(&lk;,'DESCRIPTION')"/>:</td>
									<td colspan="2" class="project-description-cell"> <!--  spans under the attribute section -->
										<xsl:call-template name="CutDescription">	
											<xsl:with-param name="Description" select="project/description"/>
											<xsl:with-param name="Width" select="'250'"/>
										</xsl:call-template>
									</td>
								</tr>
							</table>
					</div>
								
						
					</div>
				</div>
			</div>		
		
		<xsl:if test="/webcenter_page/nav/menu3">
			<ul class="ThirdLevelMenu" data-init="component/thirdlevelmenu/ThirdLevelMenu">
				<xsl:for-each select="/webcenter_page/nav/menu3">
					<xsl:if test="position() = 1"> <!-- we only want one level 3 menu: there can be one from both the page and the menu_file -->
			      		<xsl:variable name="menu" select="key('menuItemKey', @menuitemname)"/>
			      		<xsl:variable name="selection" select="@selected"/>
				  		<xsl:variable name="isEditable" select="/webcenter_page/is_project_editable" />
			
				  		<!-- Here are the actual menu items -->	
				  		<xsl:call-template name="detailsMenuLevel3">
							<xsl:with-param name="menu" select="$menu"/>
							<xsl:with-param name="selection" select="$selection"/>
							<xsl:with-param name="isEditable" select="$isEditable"/>
				  		</xsl:call-template>
				  	</xsl:if>
	    		</xsl:for-each>
			</ul>
			<xsl:if test="/webcenter_page/nav/menu4">
				<ul class="FourthLevelMenu">
					<xsl:for-each select="/webcenter_page/nav/menu4">
	      				<xsl:call-template name="detailsMenuLevel4"/>
	    			</xsl:for-each>
				</ul>
			</xsl:if>
		</xsl:if>
	</div>
	
	
  </xsl:template>
  
  
  <!--
            Template that analyzes rules to see if a given menu entry should be displayed or hidden
			We have to overwrite it here to change the handling of project_only/template_only flag
  -->
  <xsl:template name="showMenuItem">
	<xsl:param name="isEditable" select="/webcenter_page/is_project_editable"/>
	<xsl:variable name="isTemplate" select="/webcenter_page/project/is_template"/> <!-- is global, but overwritten elsewhere -->
    <xsl:call-template name="showMenuItemCommon">
	    <xsl:with-param name="isEditable" select="$isEditable"/>
	    <xsl:with-param name="isProjectContext">
	    	<xsl:choose>
	    		<xsl:when test="$isTemplate='0'"><xsl:value-of select="'1'"/></xsl:when>
	    		<xsl:otherwise><xsl:value-of select="'0'"/></xsl:otherwise>
	    	</xsl:choose>	     
	     </xsl:with-param>
	    <xsl:with-param name="isTemplateContext">
	    	<xsl:choose>
	    		<xsl:when test="$isTemplate='1'"><xsl:value-of select="'1'"/></xsl:when>
	    		<xsl:otherwise><xsl:value-of select="'0'"/></xsl:otherwise>
	    	</xsl:choose>	     
	     </xsl:with-param>
    </xsl:call-template>
  </xsl:template>
    
  <xsl:template name="detailsHref">
    <xsl:call-template name="projectDetailsHref">
      <xsl:with-param name="page" select="url"/>
      <xsl:with-param name="projectID" select="/webcenter_page/project/@id"/>
      <xsl:with-param name="folderID" select="/webcenter_page/folder/@id"/>      
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template name="projDetailsHiddenInputs">
    <xsl:call-template name="menuFileHiddenInput"/>
    <input name="projectID" value="{/webcenter_page/project/@id}" type="hidden"/>
    <input type="hidden" name="returnPage" value="{/webcenter_page/menu_file}.jsp"/>
  </xsl:template>

  <xsl:template name="filterHiddenInputs">
    <xsl:call-template name="projDetailsHiddenInputs"/>
  </xsl:template>  

  <xsl:template name="projWcTaskDetailsHiddenInputs">
    <input name="projectTaskID" value="{/webcenter_page/project_wctask/@id}" type="hidden"/>
	<input name="projectTaskName" value="{/webcenter_page/project_wctask/name}" type="hidden"/>
  </xsl:template>

  <!-- 

    template to display task name as a link to task details page

  -->
	<xsl:template name="WcTaskDetailsName">
		<xsl:param name="taskName"/>
		<xsl:param name="projectTaskID"/>
		<xsl:param name="isNameLink" select="true()"/>
		<xsl:param name="classNames" select="''"/>
		<xsl:param name="icon"/>

		<td class="{$classNames} td-nowrap">
			<span>
			<xsl:if test="not($icon = '')">
			  <a>			
				<xsl:attribute name="href">javascript:ShowTaskDetails('<xsl:value-of select="$projectTaskID"/>');</xsl:attribute>
				<xsl:if test="has_workflow = '1' and /webcenter_page/isMobileDevice = '0'">
					<xsl:attribute name="href">#</xsl:attribute>
				</xsl:if>
				<img class="add-spacing-right">
						<xsl:attribute name="src"><xsl:value-of select="$icon"/></xsl:attribute>
 					<xsl:if test="has_workflow = '1' and /webcenter_page/isMobileDevice = '0'">
						<xsl:attribute name="data-taskId"><xsl:value-of select="@id"/></xsl:attribute>
 						<xsl:attribute name="data-taskTypeId"><xsl:value-of select="task_type_id"/></xsl:attribute>
 						<xsl:attribute name="data-initialStatus"><xsl:value-of select="status/@id"/></xsl:attribute>
 						<xsl:attribute name="data-workflowName"><xsl:value-of select="name"/></xsl:attribute>
 						<xsl:attribute name="data-init">WFEditorWCR/wfPopup/WFEditorWCRPopupAnchor</xsl:attribute>
	 					<xsl:attribute name="data-masterTaskId"><xsl:value-of select="master_task_id"/></xsl:attribute>
	 					<xsl:attribute name="data-canedit"><xsl:value-of select="../canedit"/></xsl:attribute>
 						<xsl:attribute name="data-autoRefresh">1</xsl:attribute>	
					</xsl:if>				
					</img>
			  </a>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="$isNameLink">
					<a>
						<xsl:attribute name="href">javascript:ShowTaskDetails('<xsl:value-of select="$projectTaskID" />');</xsl:attribute>
						<xsl:value-of select="$taskName" />
					</a>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$taskName" />
				</xsl:otherwise>
			</xsl:choose>
			</span>	
		</td>
	</xsl:template>


  <!--

  Wizards or multi-page features should override this to hide the action bar and the details menu

-->
  <xsl:template name="isWizardPage">
    <xsl:value-of select="false()"/>
  </xsl:template>

  <!-- pages that do not have to show any links on names in the header should overwrite this -->
  <xsl:template name="isNameLink">
    <xsl:value-of select="true()"/>
  </xsl:template>
  
  <!-- 
  	Display Customer
  -->
  <xsl:template name="DisplayCustomer">
	<xsl:call-template name="DisplayCompanyLocation">
	  <xsl:with-param name="locationID" select="project/location_id"/>
	  <xsl:with-param name="companyName" select="project/customer/company/legal_name"/>
	  <xsl:with-param name="locationName" select="project/customer/location/name"/>
	</xsl:call-template>
  </xsl:template>
  
  
 <!--
	
	Template for display of projec statuses.
	Note: the values should match values from Project.ProjectStatus class
	
 -->	
   <xsl:template name="DisplayProjectStatus">
	
	<xsl:param name="isProjectEditable" select="/webcenter_page/is_project_editable &gt; 0"/>
	<xsl:param name="status" select="project/status_id"/>
	<xsl:param name="onChange" select="'PerformProjectAction(7);'"/>
	<xsl:param name="statusName" select="'status'"/>

	<xsl:variable name="wizard">
		<xsl:call-template name="isWizardPage"/>
	</xsl:variable>
	
	<xsl:choose>
		<xsl:when test="$isProjectEditable and $wizard = 'false'">
		
			<xsl:attribute name="valign"><xsl:value-of select="'bottom'"/></xsl:attribute>						
				
			<!-- Display a dropdown -->
			<select name="status" class="filter form-control"> 
				<xsl:attribute name="name">
					<xsl:value-of select="$statusName"/>
				</xsl:attribute>
				<xsl:attribute name="id">
					<xsl:value-of select="$statusName"/>
				</xsl:attribute>
			  <xsl:attribute name="onchange">
				<xsl:value-of select="$onChange"/>
			  </xsl:attribute>
				<xsl:call-template name="CreateSelectWithProjectStatusesAllowedToSet">
					<xsl:with-param name="selectedProjectStatusId" select="project/status_id" />
					<xsl:with-param name="displaySelectedIgnoreDeleted" select="true()"/>
				</xsl:call-template>		  
			</select>				   					

		</xsl:when>
		
		<xsl:otherwise>
			<!-- display R/O status -->
			<xsl:attribute name="valign"><xsl:value-of select="'baseline'"/></xsl:attribute>						
			
			<xsl:call-template name="GetLocalizedLabelOrAlternative">
				<xsl:with-param name="langKey" select="key('projectStatusKey', $status)/translation_tag" />
				<xsl:with-param name="alternativeLabel" select="key('projectStatusKey', $status)/status_name" />				
			</xsl:call-template>			
		</xsl:otherwise>
		
	</xsl:choose>
  </xsl:template>


  <!-- 
  
            template which writes the javascript needed for the project details header

  -->
  <xsl:template name="ProjDetailsJavaScript">
    <xsl:call-template name="hoversciptwithcopyright"/>
    <script src="javascript/detailswin.js" type="text/javascript"/>
	<script src="javascript/popup.js" type="text/javascript"/>
	<script src="javascript/extpopup.js" type="text/javascript"/>
	<script src="javascript/date.js" type="text/javascript"/>
	<script src="javascript/webcenter_ajax.js" type="text/javascript"/>
	<script src="javascript/webcenter_xml.js" type="text/javascript"/>
	<script src="javascript/webcenter_html.js" type="text/javascript"/>
	<script src="javascript/search.js" type="text/javascript"/>
	
	
    <script type="text/javascript">
      <xsl:text disable-output-escaping="yes">&lt;!--</xsl:text>&#xA;

	function showProjectStatusEditable( showDropDown )
	{
		// check the flag of the changeStatus to prevent that, while change the status, the non-editable version is shown
		if (document.projactionform.changeStatus.value == 1) 
			showDropDown = true ;

		if (showDropDown )
		{
			$("#ProjectStatusReadOnlyID").hide();
			$("#ProjectStatusSelectID").show();
			setTimeout('showProjectStatusEditable(false)',300);
		}
		else
		{
			if(! (document.getElementById("ProjectStatusReadOnlyID").hasMouseOver || 
					document.getElementById("ProjectStatusSelectID").hasMouseOver || 
					document.getElementById("ProjectStatusSelectID").hasFocus) ){
				$("#ProjectStatusReadOnlyID").show();
				$("#ProjectStatusSelectID").hide();	
			}else{
				setTimeout('showProjectStatusEditable(false)',300);
			}
		}
	}
	
	// listen to project status changes
	$(function(){
		$(".projectStatus ul.dropdown-menu").on("click", "a[data-id]", function(e){
			e.preventDefault();
			document.projactionform.status.value = $(this).attr("data-id");
			PerformProjectAction(7);
		});
	});
	
	
    function PerformProjectAction(choice, data)
    {
      if (choice == 1)
      {
        var folderID = document.projactionform.selectedFolderID.value;
		var projectID = document.projactionform.projectID.value;
        var projectLink = "";
        
        // mail to - do inline
        if (folderID == "") {
        	//alert("No Folder Selected");
          	//folderID not present...omit it
          	projectLink = "<xsl:value-of select="/webcenter_page/hosturl"/>" + 
        	"/projdetails.jsp?projectID=" + projectID + 
        	"&amp;menu_file=mailto";   
          } else {
	        //alert("Folder "+ folderID +" Selected");
        	//folderID is present...add it to the URL 
        	projectLink = "<xsl:value-of select="/webcenter_page/hosturl"/>" + 
        	"/projdetails.jsp?projectID=" + projectID + 
        	"&amp;curFolderID=" + folderID +
        	"&amp;menu_file=mailto";
          }
              
        // set message values
        var to = "";
        var subject = "<xsl:call-template name="encodejs"><xsl:with-param name="string" select="Lang:getStr(&lk;,'MAILTOSUBJECTPROJ')"/></xsl:call-template>";
        var doc;
        // Check to see what OS the browser is working on
        if(navigator.userAgent.toLowerCase().indexOf('win')==-1)
        	doc = "mailto:" + to + "?subject=" + encodeURIComponent(subject)  +  "&amp;body=" + encodeURIComponent(projectLink);
        else
        	doc = "mailto:" + to + "?subject=" + encodeURIComponent(subject)  +  "&amp;body=" + encodeURIComponent(projectLink);

        // pop up the email message
        window.location = doc;         
        return;
      }
      else if (choice == 2)
      {
        // add project to cart
        document.projactionform.actionVal.value="AddToCart";
      }
      else if (choice == 3)
      {
      	//data in this situation indicates whether the project is already added to favorites or not
      	if(data){
      		$(document.projactionform).append('&lt;input type="hidden" name="selectproject" value="'+document.projactionform.projectID.value+'"\&gt;')
      		document.projactionform.actionVal.value="MultRemFromFav";
      	}else{
      		// add to favorites
        	document.projactionform.actionVal.value="AddToFav";
      	}
      }
      else if (choice == 4)
      {
        // add to favorites
        document.projactionform.actionVal.value="Update";
      }
      else if (choice == 5)
      {
        // add to favorites
        document.projactionform.actionVal.value="SaveAsTmplt";
      }   
      else if (choice == 7)
      {
      	document.projactionform.changeStatus.value = 1 ;
      	
      	// What page should we return to?
      	var noArgumentsPageName = "/projdetails.jsp";
      	var currentLocation = document.location.href;
      	if(currentLocation.indexOf(noArgumentsPageName, currentLocation.length - noArgumentsPageName.length) != -1) {
      		// The url ends with "projdetails.jsp"... (so no project id and such)
      		// This can happen if we clicked the "next"/"previous" arrow for search. (See WCR-17428)
      		// In that case it will submit a POST request to this url.
      		// That means we should NOT provide this url as a return page url.
      		
      		// So, if we clicked the search button, we should simply use the default return url.
      	} else {
      		// But in all other cases it does make sense.
      		// puts the query portion of URL, related to DT98703
      		// DT98703 description: "Project Status, new dropdown list to change project status directly always redirects to project details document overview page. It would be nice if you can just use the dropdown list without changing the page."
      		document.projactionform.sourcePage_primaryChoice.value = document.location.href;
      	}
      	
        // change project status
        document.projactionform.actionVal.value="ChangeStatus";
      }
	  else if (choice == 8)
      {
        // add to favorites
        //document.projactionform.actionVal.value="ViewHistory";
		// Open a new window with project history page
		
			var projectID = "<xsl:value-of select="/webcenter_page/project/@id"/>";
			var location="javascript:OpenNewWindow('projdetailshistory.jsp?projectID=" + projectID + "');" 						 
					
			//alert('projectID=' + projectID + ' location=' + location);				
			window.location = location;
			
			return;  				
      }
      else if (choice == 9)
      {
        // add to favorites
        document.projactionform.actionVal.value="CreateNewTask";
      }
      else if (choice == 10) // search in project 
      {
		document.projactionform.actionVal.value="SearchProject" ;
      }
      else if (choice == 11) // delete project 
      {
        // delete the project
		if (!confirm('<xsl:call-template name="encodejs">
        	<xsl:with-param name="string" select="Lang:getStr(&lk;,'CONFIRM_DELETE_PROJECT')"/>
		      </xsl:call-template>?'))
        {
          return;
        }
		document.projactionform.actionVal.value="DeleteProject";
      }
      else if (choice == 12) // save as...
      {
        // Save as proejct
		window.alert('the save as... in project action still needs to be implemented');
		document.projactionform.actionVal.value="SaveAs";		
      }   
      else if (choice == 13) // upload document...
      {
		document.projactionform.actionVal.value="OpenUploadDocumentPage";		
      }
      else if (choice == 14) // upload document applet link...
      {
      	//forward to the upload applet page
		window.location.href='projdetailsdocsadddocapplet.jsp?projectID=<xsl:value-of select="/webcenter_page/project/@id"/>&amp;folderID=<xsl:value-of select="/webcenter_page/selected_folder_id"/>&amp;menu_file=<xsl:value-of select="/webcenter_page/menu_file/."/>';	
		return;
      }          
      else if (choice == 15) // download project
      {
        // download project
        document.projactionform.actionVal.value="DownloadProject";
      }
      else if (choice == 16) // create new project from this project
      {
        window.location.href='projmgmntnewproject.jsp?projectID=<xsl:value-of select="/webcenter_page/project/@id"/>&amp;menu_file=<xsl:value-of select="/webcenter_page/menu_file/."/>';	
		return;
      }          
      else if (choice == 17) // run project report
      {
      	var sourcePage = 'projdetails.jsp';

      	if (document.actionform &amp;&amp; document.actionform.sourcePage)
      		sourcePage = document.actionform.sourcePage.value;
      	else if (document.projtaskform &amp;&amp; document.projtaskform.sourcePage)
      		sourcePage = document.projtaskform.sourcePage.value;
      	else if (document.projactionform &amp;&amp; document.projactionform.sourcePage)
      		sourcePage = document.projactionform.sourcePage.value;
      		
        window.location.href='wcreportrunproject.jsp?projectID=<xsl:value-of select="/webcenter_page/project/@id"/>&amp;menu_file=<xsl:value-of select="/webcenter_page/menu_file/."/>&amp;sourcePage=' + sourcePage;	
		return;
      }          
      else if (choice == 18) // create multiple new documents...
      {
		document.projactionform.actionVal.value="OpenUploadMultiDocumentPage";		
      }
      else if (choice == 19) // link in existing projects
      {
      
        var savedSearchDialog = $("#savedSearchDia")[0].ProjectSavedSearchDialog;
        savedSearchDialog.setSearchName(data);
        savedSearchDialog.setNewChildrenAddedMessage('<xsl:call-template name="encodejs"> <xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJECT_RELATION_NEW_CHILD_LINKED')"/> </xsl:call-template>');
        savedSearchDialog.setChildrenAlreadyExistedMessage('<xsl:call-template name="encodejs"> <xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJECT_RELATION_CHILDREN_ALREADY_EXISTED')"/> </xsl:call-template>');
        savedSearchDialog.setNoProjectsSelectedMessage('<xsl:call-template name="encodejs"> <xsl:with-param name="string" select="Lang:getStr(&lk;,'PROJECT_SAVED_SEARCH_EMPTY_SELECTION')"/> </xsl:call-template>')
      	savedSearchDialog.openDialog();	
      	return;
      }
      else if (choice == 20) //create new sibling from this project
      {
      	 window.location.href='projmgmntnewproject.jsp?projectID=<xsl:value-of select="/webcenter_page/project/@id"/>&amp;menu_file=<xsl:value-of select="/webcenter_page/menu_file/."/>&amp;createchild=1';	
		 return;
      }
      else
      {
        return;
      }
            	    		
      // post the request&#xA;
      document.projactionform.submit();
    }
		
	function OpenNewWindow(href)
	{
		window.open(href);
	}
		
	function OpenTasks()
    {
		var actionHistoryUrl = "projdetailswctasks.jsp?projectID=<xsl:value-of select="/webcenter_page/project/@id"/>&amp;<xsl:call-template name="menuFileUrlParameter"/>";
		
		window.location = actionHistoryUrl;
        return;
	}
	
  <xsl:text disable-output-escaping="yes">//--&gt;</xsl:text>&#xA;
  </script>&#xA;         
  <xsl:call-template name="DateJavaScript"/>
  </xsl:template>
</xsl:stylesheet>
